@@ -1,7 +1,6 @@
 """ A simple example of some object model. """
 
 
-# Enthought library imports.
 from traits.api import HasTraits, Int, Str
 
 
@@ -9,18 +8,16 @@ class Person(HasTraits):
     """ A simple example of some object model! """
 
     # Age in years.
-    age = Int
+    age = Int()
 
     # Name.
-    name = Str
+    name = Str()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'object' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def __str__(self):
         """ Return an informal string representation of the object. """
 
         return self.name
-
-#### EOF ######################################################################
