@@ -1,29 +1,25 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ The interface for an image cache. """
 
 
-# Enthought library imports.
-from traits.api import Interface
+from traits.api import HasTraits, Interface
 
 
 class IImageCache(Interface):
     """ The interface for an image cache. """
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'object' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def __init__(self, width, height):
         """ Creates a new image cache for images of the given size.
@@ -36,9 +32,9 @@ class IImageCache(Interface):
             The height of the images in pixels
         """
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'ImageCache' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def get_image(self, filename):
         """ Returns the scaled image specified.
@@ -74,7 +70,7 @@ class IImageCache(Interface):
         """
 
 
-class MImageCache(object):
+class MImageCache(HasTraits):
     """ The mixin class that contains common code for toolkit specific
     implementations of the IImageCache interface.
     """
