@@ -1,106 +1,41 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005-2009 by Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
-#------------------------------------------------------------------------------
 """ The interface for an image resource. """
 
-try:
-    from collections.abc import Sequence
-except ImportError:  # Python 3.8 deprecation
-    from collections import Sequence
+from collections.abc import Sequence
 
+from traits.api import HasTraits, List, Str
+
+from pyface.i_image import IImage
 from pyface.resource_manager import resource_manager
 from pyface.resource.resource_path import resource_module, resource_path
-from traits.api import Interface, List, Unicode
-import six
 
 
-class IImageResource(Interface):
+class IImageResource(IImage):
     """ The interface for an image resource.
 
     An image resource describes the location of an image and provides a way
     to create a toolkit-specific image on demand.
     """
 
-    #### 'ImageResource' interface ############################################
+    # 'ImageResource' interface --------------------------------------------
 
     #: The absolute path to the image.
-    absolute_path = Unicode
+    absolute_path = Str()
 
     #: The name of the image.
-    name = Unicode
+    name = Str()
 
     #: A list of directories, classes or instances that will be used to search
     #: for the image (see the resource manager for more details).
-    search_path = List
-
-    ###########################################################################
-    # 'object' interface.
-    ###########################################################################
-
-    def __init__(self, name, search_path=None):
-        """ Creates a new image resource. """
-
-    ###########################################################################
-    # 'ImageResource' interface.
-    ###########################################################################
-
-    def create_image(self, size=None):
-        """ Creates a toolkit specific image for this resource.
-
-        Parameters
-        ----------
-        size : (int, int) or None
-            The desired size as a width, height tuple, or None if wanting
-            default image size.
-
-        Returns
-        -------
-        image : toolkit image
-            The toolkit image corresponding to the resource and the specified
-            size.
-        """
-
-    # FIXME v3: The need to distinguish between bitmaps and images is toolkit
-    # specific so, strictly speaking, the conversion to a bitmap should be done
-    # wherever the toolkit actually needs it.
-    def create_bitmap(self, size=None):
-        """ Creates a toolkit specific bitmap for this resource.
-
-        Parameters
-        ----------
-        size : (int, int) or None
-            The desired size as a width, height tuple, or None if wanting
-            default image size.
-
-        Returns
-        -------
-        image : toolkit image
-            The toolkit image corresponding to the resource and the specified
-            size as a bitmap.
-        """
-
-    def create_icon(self, size=None):
-        """ Creates a toolkit-specific icon for this resource.
-
-        Parameters
-        ----------
-        size : (int, int) or None
-            The desired size as a width, height tuple, or None if wanting
-            default image size.
-
-        Returns
-        -------
-        image : toolkit image
-            The toolkit image corresponding to the resource and the specified
-            size as an icon.
-        """
+    search_path = List()
 
     @classmethod
     def image_size(cls, image):
@@ -118,27 +53,26 @@ class IImageResource(Interface):
         """
 
 
-
-class MImageResource(object):
+class MImageResource(HasTraits):
     """ The mixin class that contains common code for toolkit specific
     implementations of the IImageResource interface.
 
     Implements: __init__(), create_image()
     """
 
-    #### Private interface ####################################################
+    # Private interface ----------------------------------------------------
 
     #: The image-not-found image.  Note that it is not a trait.
     _image_not_found = None
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'object' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def __init__(self, name, search_path=None):
         self.name = name
 
-        if isinstance(search_path, six.string_types):
+        if isinstance(search_path, str):
             _path = [search_path]
         elif isinstance(search_path, Sequence):
             _path = search_path
@@ -148,12 +82,12 @@ class MImageResource(object):
             _path = [resource_path()]
         self.search_path = _path + [resource_module()]
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'ImageResource' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def create_image(self, size=None):
-        """ Creates a toolkit specific image for this resource.
+        """ Creates a toolkit-specific image for this resource.
 
         Parameters
         ----------
@@ -176,9 +110,9 @@ class MImageResource(object):
 
         return image
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _get_ref(self, size=None):
         """ Return the resource manager reference to the image.
@@ -196,8 +130,9 @@ class MImageResource(object):
         """
 
         if self._ref is None:
-            self._ref = resource_manager.locate_image(self.name,
-                    self.search_path, size)
+            self._ref = resource_manager.locate_image(
+                self.name, self.search_path, size
+            )
 
         return self._ref
 
@@ -233,6 +168,6 @@ class MImageResource(object):
         if cls._image_not_found is None:
             from pyface.image_resource import ImageResource
 
-            cls._image_not_found = ImageResource('image_not_found')
+            cls._image_not_found = ImageResource("image_not_found")
 
         return cls._image_not_found
