@@ -1,24 +1,32 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ The implementation of a dialog that displays a message. """
 
-from __future__ import absolute_import
+
+# Import the toolkit specific version.
+from .toolkit import toolkit_object
+
+
+MessageDialog = toolkit_object("message_dialog:MessageDialog")
 
 
 # Convenience functions.
-def information(parent, message, title='Information',
-                detail='', informative=''):
+def information(
+    parent,
+    message,
+    title="Information",
+    detail="",
+    informative="",
+    text_format="auto"
+):
     """ Convenience method to show an information message dialog.
 
     Parameters
@@ -34,16 +42,31 @@ def information(parent, message, title='Information',
         "Show details").
     informative : str
         Explanatory text to display along with the message.
+    text_format : str
+        Specifies what text format to use in the resulting message dialog.
+        One of "auto", "plain", or "rich". Only supported on the qt backend.
 
     """
     dialog = MessageDialog(
-        parent=parent, message=message, title=title,
-        severity='information', detail=detail, informative=informative
+        parent=parent,
+        message=message,
+        title=title,
+        severity="information",
+        detail=detail,
+        informative=informative,
+        text_format=text_format,
     )
     dialog.open()
 
 
-def warning(parent, message, title='Warning', detail='', informative=''):
+def warning(
+    parent,
+    message,
+    title="Warning",
+    detail="",
+    informative="",
+    text_format="auto"
+):
     """ Convenience function to show a warning message dialog.
 
     Parameters
@@ -59,16 +82,31 @@ def warning(parent, message, title='Warning', detail='', informative=''):
         "Show details").
     informative : str
         Explanatory text to display along with the message.
+    text_format : str
+        Specifies what text format to use in the resulting message dialog.
+        One of "auto", "plain", or "rich". Only supported on the qt backend.
 
     """
     dialog = MessageDialog(
-        parent=parent, message=message, title=title,
-        severity='warning', detail=detail, informative=informative
+        parent=parent,
+        message=message,
+        title=title,
+        severity="warning",
+        detail=detail,
+        informative=informative,
+        text_format=text_format,
     )
     dialog.open()
 
 
-def error(parent, message, title='Error', detail='', informative=''):
+def error(
+    parent,
+    message,
+    title="Error",
+    detail="",
+    informative="",
+    text_format="auto"
+):
     """ Convenience function to show an error message dialog.
 
     Parameters
@@ -84,17 +122,18 @@ def error(parent, message, title='Error', detail='', informative=''):
         "Show details").
     informative : str
         Explanatory text to display along with the message.
+    text_format : str
+        Specifies what text format to use in the resulting message dialog.
+        One of "auto", "plain", or "rich". Only supported on the qt backend.
 
     """
     dialog = MessageDialog(
-        parent=parent, message=message, title=title, severity='error',
-        detail=detail, informative=informative
+        parent=parent,
+        message=message,
+        title=title,
+        severity="error",
+        detail=detail,
+        informative=informative,
+        text_format=text_format,
     )
     dialog.open()
-
-
-# Import the toolkit specific version.
-from .toolkit import toolkit_object
-MessageDialog = toolkit_object('message_dialog:MessageDialog')
-
-#### EOF ######################################################################
