@@ -1,17 +1,18 @@
-# Copyright (c) 2010-18, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 
-# Enthought library imports.
-from pyface.action.api import Action, ActionItem, Group
-from traits.api import Any, List, Instance, Property, Unicode, on_trait_change
 
-# Local imports.
+from pyface.action.api import Action, ActionItem, Group
+from traits.api import Any, List, Instance, Property, Str, observe
+
+
 from pyface.tasks.task import Task
 from pyface.tasks.task_window import TaskWindow
 
@@ -20,27 +21,28 @@ class TaskToggleAction(Action):
     """ An action for activating a task.
     """
 
-    #### 'Action' interface ###################################################
+    # 'Action' interface ---------------------------------------------------
 
     #: The user-visible name of the action, matches the task name.
-    name = Property(Unicode, depends_on='task.name')
+    name = Property(Str, observe="task.name")
 
     #: The action is a toggle menu item.
-    style = 'toggle'
+    style = "toggle"
 
     #: The tooltip to display for the menu item.
-    tooltip = Property(Unicode, depends_on='name')
+    tooltip = Property(Str, observe="name")
 
-    #### 'TaskActivateAction' interface #######################################
+    # 'TaskToggleAction' interface -----------------------------------------
 
+    #: The Task with which the action is associated.
     task = Instance(Task)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'Action' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def destroy(self):
-        super(TaskToggleAction, self).destroy()
+        super().destroy()
 
         # Make sure that we are not listening to changes in the task anymore
         # In traits style, we will set the basic object to None and have the
@@ -51,20 +53,20 @@ class TaskToggleAction(Action):
         window = self.task.window
         window.activate_task(self.task)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _get_name(self):
         if self.task is None:
-            return 'UNDEFINED'
+            return "UNDEFINED"
         return self.task.name
 
     def _get_tooltip(self):
-        return u'Switch to the %s task.' % self.name
+        return "Switch to the %s task." % self.name
 
-    @on_trait_change('task.window.active_task')
-    def _update_checked(self):
+    @observe("task.window.active_task")
+    def _update_checked(self, event):
         if self.task:
             window = self.task.window
             self.checked = (
@@ -76,35 +78,34 @@ class TaskToggleGroup(Group):
     """ A menu for changing the active task in a task window.
     """
 
-    #### 'ActionManager' interface ############################################
+    # 'ActionManager' interface --------------------------------------------
 
-    id = 'TaskToggleGroup'
-    items = List
+    id = "TaskToggleGroup"
+    items = List()
 
-    #### 'TaskChangeMenuManager' interface ####################################
+    # 'TaskToggleGroup' interface ------------------------------------------
 
-    # The ActionManager to which the group belongs.
-    manager = Any
+    #: The ActionManager to which the group belongs.
+    manager = Any()
 
-    # The window that contains the group.
+    #: The window that contains the group.
     window = Instance(TaskWindow)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _get_items(self):
         items = []
         if len(self.window.tasks) > 1:
             # at least two tasks, so something to toggle
             items = [
-                ActionItem(
-                    action=TaskToggleAction(task=task),
-                ) for task in self.window.tasks
+                ActionItem(action=TaskToggleAction(task=task))
+                for task in self.window.tasks
             ]
         return items
 
-    def _rebuild(self):
+    def _rebuild(self, event):
         # Clear out the old group, then build the new one.
         self.destroy()
         self.items = self._get_items()
@@ -112,10 +113,10 @@ class TaskToggleGroup(Group):
         # Inform our manager that it needs to be rebuilt.
         self.manager.changed = True
 
-    #### Trait initializers ###################################################
+    # Trait initializers ---------------------------------------------------
 
     def _items_default(self):
-        self.window.on_trait_change(self._rebuild, 'tasks[]')
+        self.window.observe(self._rebuild, "tasks.items")
         return self._get_items()
 
     def _manager_default(self):
@@ -125,4 +126,4 @@ class TaskToggleGroup(Group):
         return manager
 
     def _window_default(self):
-        return self.manager.controller.task.window
\ No newline at end of file
+        return self.manager.controller.task.window
