@@ -1,12 +1,20 @@
-# Enthought library imports.
-from pyface.action.api import StatusBarManager
-from traits.api import Callable, HasTraits, Instance, List, Str, \
-     Unicode
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
-# Local imports.
-from action.schema import MenuBarSchema, ToolBarSchema
-from action.schema_addition import SchemaAddition
-from task_layout import TaskLayout
+from pyface.action.api import StatusBarManager
+from traits.api import Callable, HasTraits, Instance, List, Str
+
+
+from .action.schema import MenuBarSchema, ToolBarSchema
+from .action.schema_addition import SchemaAddition
+from pyface.tasks.task_layout import TaskLayout
 
 
 class Task(HasTraits):
@@ -17,41 +25,42 @@ class Task(HasTraits):
     its view (a TaskWindow) and an application-specific model.
     """
 
-    # The task's identifier.
-    id = Str
+    #: The task's identifier.
+    id = Str()
 
-    # The task's user-visible name.
-    name = Unicode
+    #: The task's user-visible name.
+    name = Str()
 
-    # The default layout to use for the task. If not overridden, only the
-    # central pane is displayed.
+    #: The default layout to use for the task. If not overridden, only the
+    #: central pane is displayed.
     default_layout = Instance(TaskLayout, ())
 
-    # A list of extra IDockPane factories for the task. These dock panes are
-    # used in conjunction with the dock panes returned by create_dock_panes().
+    #: A list of extra IDockPane factories for the task. These dock panes are
+    #: used in conjunction with the dock panes returned by
+    #: create_dock_panes().
     extra_dock_pane_factories = List(Callable)
 
-    # The window to which the task is attached. Set by the framework.
-    window = Instance('pyface.tasks.task_window.TaskWindow')
+    #: The window to which the task is attached. Set by the framework.
+    window = Instance("pyface.tasks.task_window.TaskWindow")
 
-    #### Actions ##############################################################
+    # Actions -------------------------------------------------------------#
 
-    # The menu bar for the task.
+    #: The menu bar for the task.
     menu_bar = Instance(MenuBarSchema)
 
-    # The (optional) status bar for the task.
+    #: The (optional) status bar for the task.
     status_bar = Instance(StatusBarManager)
 
-    # The list of tool bars for the tasks.
+    #: The list of tool bars for the tasks.
     tool_bars = List(ToolBarSchema)
 
-    # A list of extra actions, groups, and menus that are inserted into menu
-    # bars and tool bars constructed from the above schemas.
+    #: A list of extra actions, groups, and menus that are inserted into menu
+    #: bars and tool bars constructed from the above schemas.
     extra_actions = List(SchemaAddition)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'Task' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def activated(self):
         """ Called after the task has been activated in a TaskWindow.
@@ -61,7 +70,7 @@ class Task(HasTraits):
     def create_central_pane(self):
         """ Create and return the central pane, which must implement ITaskPane.
         """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def create_dock_panes(self):
         """ Create and return the task's dock panes (IDockPane instances).
