@@ -1,4 +1,13 @@
-from __future__ import absolute_import
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 
 import unittest
 
@@ -6,7 +15,6 @@ from ..system_metrics import SystemMetrics
 
 
 class TestSystemMetrics(unittest.TestCase):
-
     def setUp(self):
         self.metrics = SystemMetrics()
 
