@@ -1,4 +1,13 @@
-from __future__ import absolute_import
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 
 import platform
 import unittest
@@ -7,23 +16,23 @@ from ..constant import CANCEL, NO, OK, YES
 from ..toolkit import toolkit_object
 from ..window import Window
 
-is_qt = toolkit_object.toolkit == 'qt4'
+is_qt = toolkit_object.toolkit == "qt4"
 if is_qt:
     from pyface.qt import qt_api
 
-GuiTestAssistant = toolkit_object('util.gui_test_assistant:GuiTestAssistant')
-no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
+GuiTestAssistant = toolkit_object("util.gui_test_assistant:GuiTestAssistant")
+no_gui_test_assistant = GuiTestAssistant.__name__ == "Unimplemented"
 
 ModalDialogTester = toolkit_object(
-    'util.modal_dialog_tester:ModalDialogTester'
+    "util.modal_dialog_tester:ModalDialogTester"
 )
-no_modal_dialog_tester = (ModalDialogTester.__name__ == 'Unimplemented')
+no_modal_dialog_tester = ModalDialogTester.__name__ == "Unimplemented"
 
-is_pyqt5 = (is_qt and qt_api == 'pyqt5')
-is_pyqt4_linux = (is_qt and qt_api == 'pyqt' and platform.system() == 'Linux')
+is_pyqt5 = is_qt and qt_api == "pyqt5"
+is_pyqt4_linux = is_qt and qt_api == "pyqt" and platform.system() == "Linux"
 
 
-@unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
+@unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
 class TestWindow(unittest.TestCase, GuiTestAssistant):
     def setUp(self):
         GuiTestAssistant.setUp(self)
@@ -43,13 +52,13 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
 
     def test_open_close(self):
         # test that opening and closing works as expected
-        with self.assertTraitChanges(self.window, 'opening', count=1):
-            with self.assertTraitChanges(self.window, 'opened', count=1):
+        with self.assertTraitChanges(self.window, "opening", count=1):
+            with self.assertTraitChanges(self.window, "opened", count=1):
                 with self.event_loop():
                     self.window.open()
 
-        with self.assertTraitChanges(self.window, 'closing', count=1):
-            with self.assertTraitChanges(self.window, 'closed', count=1):
+        with self.assertTraitChanges(self.window, "closing", count=1):
+            with self.assertTraitChanges(self.window, "closed", count=1):
                 with self.event_loop():
                     self.window.close()
 
@@ -130,7 +139,7 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
         with self.event_loop():
             self.window.visible = False
 
-        with self.assertTraitChanges(self.window, 'visible', count=1):
+        with self.assertTraitChanges(self.window, "visible", count=1):
             with self.event_loop():
                 self.window.control.show()
 
@@ -140,19 +149,19 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
         with self.event_loop():
             self.window.open()
 
-        with self.assertTraitChanges(self.window, 'visible', count=1):
+        with self.assertTraitChanges(self.window, "visible", count=1):
             with self.event_loop():
                 self.window.control.hide()
 
         self.assertFalse(self.window.visible)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     @unittest.skipIf(
         is_pyqt5, "Confirmation dialog click tests don't work on pyqt5."
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Confirmation dialog click tests don't work reliably on linux.  Issue #282."
+        "Confirmation dialog click tests don't work reliably on linux.  Issue #282.",
     )
     def test_confirm_reject(self):
         # test that cancel works as expected
@@ -163,13 +172,13 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
 
         self.assertEqual(tester.result, CANCEL)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     @unittest.skipIf(
         is_pyqt5, "Confirmation dialog click tests don't work on pyqt5."
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Confirmation dialog click tests don't work reliably on linux.  Issue #282."
+        "Confirmation dialog click tests don't work reliably on linux.  Issue #282.",
     )
     def test_confirm_yes(self):
         # test that yes works as expected
@@ -178,13 +187,13 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
 
         self.assertEqual(tester.result, YES)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     @unittest.skipIf(
         is_pyqt5, "Confirmation dialog click tests don't work on pyqt5."
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Confirmation dialog click tests don't work reliably on linux.  Issue #282."
+        "Confirmation dialog click tests don't work reliably on linux.  Issue #282.",
     )
     def test_confirm_no(self):
         # test that no works as expected
@@ -193,13 +202,13 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
 
         self.assertEqual(tester.result, NO)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     @unittest.skipIf(
         is_pyqt5, "Confirmation dialog click tests don't work on pyqt5."
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Confirmation dialog click tests don't work reliably on linux.  Issue #282."
+        "Confirmation dialog click tests don't work reliably on linux.  Issue #282.",
     )
     def test_confirm_cancel(self):
         # test that cncel works as expected
@@ -210,47 +219,47 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
 
         self.assertEqual(tester.result, CANCEL)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_information_accept(self):
         self._check_message_dialog_accept(self.window.information)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     @unittest.skipIf(
         is_pyqt5, "Message dialog click tests don't work on pyqt5."
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Message dialog click tests don't work reliably on linux.  Issue #282."
+        "Message dialog click tests don't work reliably on linux.  Issue #282.",
     )
     def test_information_ok(self):
         self._check_message_dialog_ok(self.window.information)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_warning_accept(self):
         self._check_message_dialog_accept(self.window.warning)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     @unittest.skipIf(
         is_pyqt5, "Message dialog click tests don't work on pyqt5."
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Message dialog click tests don't work reliably on linux.  Issue #282."
+        "Message dialog click tests don't work reliably on linux.  Issue #282.",
     )
     def test_warning_ok(self):
         self._check_message_dialog_ok(self.window.warning)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_error_accept(self):
         self._check_message_dialog_accept(self.window.error)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     @unittest.skipIf(
         is_pyqt5, "Message dialog click tests don't work on pyqt5."
     )
     @unittest.skipIf(
         is_pyqt4_linux,
-        "Message dialog click tests don't work reliably on linux.  Issue #282."
+        "Message dialog click tests don't work reliably on linux.  Issue #282.",
     )
     def test_error_ok(self):
         self._check_message_dialog_ok(self.window.error)
@@ -269,9 +278,9 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
 
     def _setup_tester(self, method):
         kwargs = {
-            'title': 'Title',
-            'detail': 'Detail',
-            'informative': 'Informative'
+            "title": "Title",
+            "detail": "Detail",
+            "informative": "Informative",
         }
         tester = ModalDialogTester(lambda: method("message", **kwargs))
         return tester
