@@ -1,18 +1,34 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005-2017, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
-from __future__ import absolute_import
+
+"""
+
+API for the ``pyface.tree`` subpackage.
+
+- :class:`~.NodeEvent`
+- :class:`~.NodeMonitor`
+- :class:`~.NodeManager`
+- :class:`~.NodeTree`
+- :class:`~.NodeTreeModel`
+- :class:`~.NodeType`
+- :class:`~.TraitDictNodeType`
+- :class:`~.TraitListNodeType`
+- :class:`~.TreeModel`
+
+Note that the following classes are only available in the Wx toolkit at the
+moment.
+
+- :class:`~.Tree`.
+
+"""
 
 from .node_event import NodeEvent
 from .node_monitor import NodeMonitor
