@@ -1,23 +1,19 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ The model for a tree control with extensible node types. """
 
 
-# Enthought library imports.
 from traits.api import Dict, Instance
 
-# Local imports.
+
 from .node_manager import NodeManager
 from .tree_model import TreeModel
 
@@ -25,19 +21,19 @@ from .tree_model import TreeModel
 class NodeTreeModel(TreeModel):
     """ The model for a tree control with extensible node types. """
 
-    #### 'NodeTreeModel' interface ############################################
+    # 'NodeTreeModel' interface --------------------------------------------
 
     # The node manager looks after all node types.
     node_manager = Instance(NodeManager, ())
 
-    #### Private interface ####################################################
+    # Private interface ----------------------------------------------------
 
     # Node monitors.
-    _monitors = Dict
+    _monitors = Dict()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'TreeModel' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def has_children(self, node):
         """ Returns True if a node has children, otherwise False.
@@ -112,8 +108,6 @@ class NodeTreeModel(TreeModel):
 
         node_type.drop(node, data)
 
-        return
-
     def get_image(self, node, selected, expanded):
         """ Returns the label image for a node.
 
@@ -219,8 +213,6 @@ class NodeTreeModel(TreeModel):
             self._start_monitor(monitor)
             self._monitors[self.node_manager.get_key(node)] = monitor
 
-        return
-
     def remove_listener(self, node):
         """ Removes a listener for changes to a node. """
 
@@ -233,9 +225,9 @@ class NodeTreeModel(TreeModel):
 
         return
 
-    #########################################################################
+    # ------------------------------------------------------------------------
     # 'NodeTreeModel' interface.
-    #########################################################################
+    # ------------------------------------------------------------------------
 
     def get_context_menu(self, node):
         """ Returns the context menu for a node. """
@@ -245,119 +237,88 @@ class NodeTreeModel(TreeModel):
 
         return node_type.get_context_menu(node)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'Private' interface
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _start_monitor(self, monitor):
         """ Starts a monitor. """
 
-        monitor.on_trait_change(
-            self._on_nodes_changed, 'nodes_changed'
-        )
+        monitor.observe(self._on_nodes_changed, "nodes_changed")
 
-        monitor.on_trait_change(
-            self._on_nodes_inserted, 'nodes_inserted'
-        )
+        monitor.observe(self._on_nodes_inserted, "nodes_inserted")
 
-        monitor.on_trait_change(
-            self._on_nodes_removed, 'nodes_removed'
-        )
+        monitor.observe(self._on_nodes_removed, "nodes_removed")
 
-        monitor.on_trait_change(
-            self._on_nodes_replaced, 'nodes_replaced'
-        )
+        monitor.observe(self._on_nodes_replaced, "nodes_replaced")
 
-        monitor.on_trait_change(
-            self._on_structure_changed, 'structure_changed'
-        )
+        monitor.observe(self._on_structure_changed, "structure_changed")
 
         monitor.start()
 
-        return
-
     def _stop_monitor(self, monitor):
         """ Stops a monitor. """
 
-        monitor.on_trait_change(
-            self._on_nodes_changed, 'nodes_changed', remove=True
-        )
+        monitor.observe(self._on_nodes_changed, "nodes_changed", remove=True)
 
-        monitor.on_trait_change(
-            self._on_nodes_inserted, 'nodes_inserted', remove=True
-        )
+        monitor.observe(self._on_nodes_inserted, "nodes_inserted", remove=True)
 
-        monitor.on_trait_change(
-            self._on_nodes_removed, 'nodes_removed', remove=True
-        )
+        monitor.observe(self._on_nodes_removed, "nodes_removed", remove=True)
 
-        monitor.on_trait_change(
-            self._on_nodes_replaced, 'nodes_replaced', remove=True
-        )
+        monitor.observe(self._on_nodes_replaced, "nodes_replaced", remove=True)
 
-
-        monitor.on_trait_change(
-            self._on_structure_changed, 'structure_changed', remove=True
+        monitor.observe(
+            self._on_structure_changed, "structure_changed", remove=True
         )
 
         monitor.stop()
 
         return
 
-    #### Trait event handlers #################################################
+    # Trait event handlers -------------------------------------------------
 
-    #### Static ####
+    # Static ----
 
     # fixme: Commented this out as listeners are added and removed by the tree.
     # This caused duplicate monitors to be created for the root node.
-##     def _root_changed(self, old, new):
-##         """ Called when the root of the model has been changed. """
+    ##     def _root_changed(self, old, new):
+    ##         """ Called when the root of the model has been changed. """
 
-##         if old is not None:
-##             # Remove a listener for structure/appearance changes
-##             self.remove_listener(old)
+    ##         if old is not None:
+    ##             # Remove a listener for structure/appearance changes
+    ##             self.remove_listener(old)
 
-##         if new is not None:
-##             # Wire up a listener for structure/appearance changes
-##             self.add_listener(new)
+    ##         if new is not None:
+    ##             # Wire up a listener for structure/appearance changes
+    ##             self.add_listener(new)
 
-##         return
+    ##         return
 
-    #### Dynamic ####
+    # Dynamic ----
 
-    def _on_nodes_changed(self, monitor, trait_name, event):
+    def _on_nodes_changed(self, event):
         """ Called when nodes have changed. """
 
-        self.nodes_changed = event
+        self.nodes_changed = event.new
 
-        return
-
-    def _on_nodes_inserted(self, monitor, trait_name, event):
+    def _on_nodes_inserted(self, event):
         """ Called when nodes have been inserted. """
 
-        self.nodes_inserted = event
+        self.nodes_inserted = event.new
 
-        return
-
-    def _on_nodes_removed(self, monitor, trait_name, event):
+    def _on_nodes_removed(self, event):
         """ Called when nodes have been removed. """
 
-        self.nodes_removed = event
+        self.nodes_removed = event.new
 
-        return
-
-    def _on_nodes_replaced(self, monitor, trait_name, event):
+    def _on_nodes_replaced(self, event):
         """ Called when nodes have been replaced. """
 
-        self.nodes_replaced = event
+        self.nodes_replaced = event.new
 
-        return
-
-    def _on_structure_changed(self, monitor, trait_name, event):
+    def _on_structure_changed(self, event):
         """ Called when the structure of a node has changed drastically. """
 
-        self.structure_changed = event
+        self.structure_changed = event.new
 
         return
-
-#### EOF ######################################################################
