@@ -1,33 +1,28 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 
-# Enthought library imports.
 from pyface.resource.api import ResourceFactory
 
 
 class PyfaceResourceFactory(ResourceFactory):
     """ The implementation of a shared resource manager. """
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'ResourceFactory' toolkit interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def image_from_file(self, filename):
         """ Creates an image from the data in the specified filename. """
         # Just return the data as a string for now.
-        f = open(filename, 'rb')
+        f = open(filename, "rb")
         data = f.read()
         f.close()
 
@@ -36,5 +31,3 @@ class PyfaceResourceFactory(ResourceFactory):
     def image_from_data(self, data):
         """ Creates an image from the specified data. """
         return data
-
-#### EOF ######################################################################
