@@ -1,28 +1,27 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2009, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 #
 # Author: Evan Patterson
 # Date: 06/26/09
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
-# Standard library imports
 from io import BytesIO
-from six.moves.cPickle import dumps, load, loads
+from pickle import dumps, load, loads
+
 
-# System library imports
 from pyface.qt import QtCore, QtGui
 
-# ETS imports
+
 from traits.api import provides
 from pyface.i_clipboard import IClipboard, BaseClipboard
-import six
 
 # Shortcuts
 cb = QtGui.QApplication.clipboard()
@@ -34,23 +33,25 @@ PYTHON_TYPE = "python/object"
 @provides(IClipboard)
 class Clipboard(BaseClipboard):
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
     #  'data' property methods:
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def _get_has_data(self):
         return self.has_object_data or self.has_text_data or self.has_file_data
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
     #  'object_data' property methods:
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def _get_object_data(self):
         obj = None
         mime_data = cb.mimeData()
         if mime_data.hasFormat(PYTHON_TYPE):
             serialized_data = BytesIO(mime_data.data(PYTHON_TYPE).data())
-            klass = load(serialized_data)
+            # Loading the serialized data the first time returns the klass
+            _ = load(serialized_data)
+            # Loading it a second time returns the actual object
             obj = load(serialized_data)
         return obj
 
@@ -64,7 +65,7 @@ class Clipboard(BaseClipboard):
         return cb.mimeData().hasFormat(PYTHON_TYPE)
 
     def _get_object_type(self):
-        result = ''
+        result = ""
         mime_data = cb.mimeData()
         if mime_data.hasFormat(PYTHON_TYPE):
             try:
@@ -74,9 +75,9 @@ class Clipboard(BaseClipboard):
                 pass
         return result
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
     #  'text_data' property methods:
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def _get_text_data(self):
         return cb.text()
@@ -87,9 +88,9 @@ class Clipboard(BaseClipboard):
     def _get_has_text_data(self):
         return cb.mimeData().hasText()
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
     #  'file_data' property methods:
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def _get_file_data(self):
         mime_data = cb.mimeData()
@@ -99,11 +100,11 @@ class Clipboard(BaseClipboard):
             return []
 
     def _set_file_data(self, data):
-        if isinstance(data, six.string_types):
+        if isinstance(data, str):
             data = [data]
         mime_data = QtCore.QMimeData()
         mime_data.setUrls([QtCore.QUrl(path) for path in data])
         cb.setMimeData(mime_data)
 
-    def _get_has_file_data (self):
+    def _get_has_file_data(self):
         return cb.mimeData().hasUrls()
