@@ -1,39 +1,39 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2010, Enthought Inc
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
-# This software is provided without warranty under the terms of the BSD license.
-
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-# Author: Enthought Inc
-# Description: <Enthought pyface code editor>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 
-# Standard library imports
-import math
 import sys
 
-# System library imports
+
 from pyface.qt import QtCore, QtGui
 
-# Local imports
-from find_widget import FindWidget
-from gutters import LineNumberWidget, StatusGutterWidget
-from replace_widget import ReplaceWidget
-from pygments_highlighter import PygmentsHighlighter
+
+from .find_widget import FindWidget
+from .gutters import LineNumberWidget, StatusGutterWidget
+from .replace_widget import ReplaceWidget
+from .pygments_highlighter import PygmentsHighlighter
 
 
 class CodeWidget(QtGui.QPlainTextEdit):
     """ A widget for viewing and editing code.
     """
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # CodeWidget interface
-    ###########################################################################
+    # ------------------------------------------------------------------------
+    focus_lost = QtCore.Signal()
 
-    def __init__(self, parent, should_highlight_current_line=True, font=None,
-                 lexer=None):
-        super(CodeWidget, self).__init__(parent)
+    def __init__(
+        self, parent, should_highlight_current_line=False, font=None, lexer=None
+    ):
+        super().__init__(parent)
 
         self.highlighter = PygmentsHighlighter(self.document(), lexer)
         self.line_number_widget = LineNumberWidget(self)
@@ -42,15 +42,15 @@ class CodeWidget(QtGui.QPlainTextEdit):
         if font is None:
             # Set a decent fixed width font for this platform.
             font = QtGui.QFont()
-            if sys.platform == 'win32':
+            if sys.platform == "win32":
                 # Prefer Consolas, but fall back to Courier if necessary.
-                font.setFamily('Consolas')
+                font.setFamily("Consolas")
                 if not font.exactMatch():
-                    font.setFamily('Courier')
-            elif sys.platform == 'darwin':
-                font.setFamily('Monaco')
+                    font.setFamily("Courier")
+            elif sys.platform == "darwin":
+                font.setFamily("Monaco")
             else:
-                font.setFamily('Monospace')
+                font.setFamily("Monospace")
             font.setStyleHint(QtGui.QFont.TypeWriter)
         self.set_font(font)
 
@@ -58,7 +58,7 @@ class CodeWidget(QtGui.QPlainTextEdit):
         self.should_highlight_current_line = should_highlight_current_line
 
         # What that highlight color should be.
-        self.line_highlight_color = QtGui.QColor(QtCore.Qt.yellow).lighter(160)
+        self.line_highlight_color = self.palette().alternateBase()
 
         # Auto-indentation behavior
         self.auto_indent = True
@@ -68,8 +68,8 @@ class CodeWidget(QtGui.QPlainTextEdit):
         self.tabs_as_spaces = True
         self.tab_width = 4
 
-        self.indent_character = ':'
-        self.comment_character = '#'
+        self.indent_character = ":"
+        self.comment_character = "#"
 
         # Set up gutter widget and current line highlighting
         self.blockCountChanged.connect(self.update_line_number_width)
@@ -80,13 +80,22 @@ class CodeWidget(QtGui.QPlainTextEdit):
         self.highlight_current_line()
 
         # Don't wrap text
-        self.setLineWrapMode(QtGui.QPlainTextEdit.NoWrap)
+        self.setLineWrapMode(QtGui.QPlainTextEdit.LineWrapMode.NoWrap)
 
         # Key bindings
-        self.indent_key = QtGui.QKeySequence(QtCore.Qt.Key_Tab)
-        self.unindent_key = QtGui.QKeySequence(QtCore.Qt.SHIFT + QtCore.Qt.Key_Backtab)
-        self.comment_key = QtGui.QKeySequence(QtCore.Qt.CTRL + QtCore.Qt.Key_Slash)
-        self.backspace_key = QtGui.QKeySequence(QtCore.Qt.Key_Backspace)
+        self.indent_key = QtGui.QKeySequence(QtCore.Qt.Key.Key_Tab)
+        self.unindent_key = QtGui.QKeySequence(
+            QtCore.Qt.Modifier.SHIFT + QtCore.Qt.Key.Key_Backtab
+        )
+        self.comment_key = QtGui.QKeySequence(
+            QtCore.Qt.Modifier.CTRL + QtCore.Qt.Key.Key_Slash
+        )
+        self.backspace_key = QtGui.QKeySequence(QtCore.Qt.Key.Key_Backspace)
+
+    def _remove_event_listeners(self):
+        self.blockCountChanged.disconnect(self.update_line_number_width)
+        self.updateRequest.disconnect(self.update_line_numbers)
+        self.cursorPositionChanged.disconnect(self.highlight_current_line)
 
     def lines(self):
         """ Return the number of lines.
@@ -128,7 +137,7 @@ class CodeWidget(QtGui.QPlainTextEdit):
     def get_selected_text(self):
         """ Return the currently selected text.
         """
-        return unicode(self.textCursor().selectedText())
+        return str(self.textCursor().selectedText())
 
     def set_font(self, font):
         """ Set the new QFont.
@@ -151,7 +160,8 @@ class CodeWidget(QtGui.QPlainTextEdit):
         if dy:
             self.line_number_widget.scroll(0, dy)
         self.line_number_widget.update(
-            0, rect.y(), self.line_number_widget.width(), rect.height())
+            0, rect.y(), self.line_number_widget.width(), rect.height()
+        )
         if rect.contains(self.viewport().rect()):
             self.update_line_number_width()
 
@@ -174,15 +184,16 @@ class CodeWidget(QtGui.QPlainTextEdit):
             selection = QtGui.QTextEdit.ExtraSelection()
             selection.format.setBackground(self.line_highlight_color)
             selection.format.setProperty(
-                QtGui.QTextFormat.FullWidthSelection, True)
+                QtGui.QTextFormat.Property.FullWidthSelection, True
+            )
             selection.cursor = self.textCursor()
             selection.cursor.clearSelection()
             self.setExtraSelections([selection])
 
     def autoindent_newline(self):
-        tab = '\t'
+        tab = "\t"
         if self.tabs_as_spaces:
-            tab = ' '*self.tab_width
+            tab = " " * self.tab_width
 
         cursor = self.textCursor()
         text = cursor.block().text()
@@ -243,7 +254,7 @@ class CodeWidget(QtGui.QPlainTextEdit):
             cursor.beginEditBlock()
 
             removed = self.line_unindent(cursor)
-            position = max(position-removed, 0)
+            position = max(position - removed, 0)
 
             cursor.endEditBlock()
             cursor.setPosition(position)
@@ -291,8 +302,10 @@ class CodeWidget(QtGui.QPlainTextEdit):
             comment = True
             for block in sel_blocks:
                 text = block.text()
-                if len(text) > indent_pos and \
-                        text[indent_pos] == self.comment_character:
+                if (
+                    len(text) > indent_pos
+                    and text[indent_pos] == self.comment_character
+                ):
                     # Already commented.
                     comment = False
                     break
@@ -304,7 +317,7 @@ class CodeWidget(QtGui.QPlainTextEdit):
                 cursor.setPosition(block.position())
                 if comment:
                     if block.length() < indent_pos:
-                        cursor.insertText(' ' * indent_pos)
+                        cursor.insertText(" " * indent_pos)
                     self.line_comment(cursor, indent_pos)
                 else:
                     self.line_uncomment(cursor, indent_pos)
@@ -312,24 +325,26 @@ class CodeWidget(QtGui.QPlainTextEdit):
             self._show_selected_blocks(sel_blocks)
 
     def line_comment(self, cursor, position):
-        cursor.movePosition(QtGui.QTextCursor.StartOfBlock)
-        cursor.movePosition(QtGui.QTextCursor.Right,
-                            QtGui.QTextCursor.MoveAnchor, position)
+        cursor.movePosition(QtGui.QTextCursor.MoveOperation.StartOfBlock)
+        cursor.movePosition(
+            QtGui.QTextCursor.MoveOperation.Right, QtGui.QTextCursor.MoveMode.MoveAnchor, position
+        )
         cursor.insertText(self.comment_character)
 
     def line_uncomment(self, cursor, position=0):
-        cursor.movePosition(QtGui.QTextCursor.StartOfBlock)
+        cursor.movePosition(QtGui.QTextCursor.MoveOperation.StartOfBlock)
         text = cursor.block().text()
-        new_text = text[:position] + text[position+1:]
-        cursor.movePosition(QtGui.QTextCursor.EndOfBlock,
-                            QtGui.QTextCursor.KeepAnchor)
+        new_text = text[:position] + text[position + 1:]
+        cursor.movePosition(
+            QtGui.QTextCursor.MoveOperation.EndOfBlock, QtGui.QTextCursor.MoveMode.KeepAnchor
+        )
         cursor.removeSelectedText()
         cursor.insertText(new_text)
 
     def line_indent(self, cursor):
-        tab = '\t'
+        tab = "\t"
         if self.tabs_as_spaces:
-            tab = '    '
+            tab = "    "
 
         cursor.insertText(tab)
 
@@ -337,15 +352,16 @@ class CodeWidget(QtGui.QPlainTextEdit):
         """ Unindents the cursor's line. Returns the number of characters
             removed.
         """
-        tab = '\t'
+        tab = "\t"
         if self.tabs_as_spaces:
-            tab = '    '
+            tab = "    "
 
-        cursor.movePosition(QtGui.QTextCursor.StartOfBlock)
+        cursor.movePosition(QtGui.QTextCursor.MoveOperation.StartOfBlock)
         if cursor.block().text().startswith(tab):
             new_text = cursor.block().text()[len(tab):]
-            cursor.movePosition(QtGui.QTextCursor.EndOfBlock,
-                                QtGui.QTextCursor.KeepAnchor)
+            cursor.movePosition(
+                QtGui.QTextCursor.MoveOperation.EndOfBlock, QtGui.QTextCursor.MoveMode.KeepAnchor
+            )
             cursor.removeSelectedText()
             cursor.insertText(new_text)
             return len(tab)
@@ -356,12 +372,12 @@ class CodeWidget(QtGui.QPlainTextEdit):
         """ Return the word under the cursor.
         """
         cursor = self.textCursor()
-        cursor.select(QtGui.QTextCursor.WordUnderCursor)
-        return unicode(cursor.selectedText())
+        cursor.select(QtGui.QTextCursor.SelectionType.WordUnderCursor)
+        return str(cursor.selectedText())
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # QWidget interface
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     # FIXME: This is a quick hack to be able to access the keyPressEvent
     # from the rest editor. This should be changed to work within the traits
@@ -370,28 +386,32 @@ class CodeWidget(QtGui.QPlainTextEdit):
         pass
 
     def keyPressEvent(self, event):
+        if self.isReadOnly():
+            return super().keyPressEvent(event)
+
         key_sequence = QtGui.QKeySequence(event.key() + int(event.modifiers()))
 
-        self.keyPressEvent_action(event) # FIXME: see above
+        self.keyPressEvent_action(event)  # FIXME: see above
 
         # If the cursor is in the middle of the first line, pressing the "up"
         # key causes the cursor to go to the start of the first line, i.e. the
         # beginning of the document. Likewise, if the cursor is somewhere in the
         # last line, the "down" key causes it to go to the end.
         cursor = self.textCursor()
-        if key_sequence.matches(QtGui.QKeySequence(QtCore.Qt.Key_Up)):
-            cursor.movePosition(QtGui.QTextCursor.StartOfLine)
+        if key_sequence.matches(QtGui.QKeySequence(QtCore.Qt.Key.Key_Up)):
+            cursor.movePosition(QtGui.QTextCursor.MoveOperation.StartOfLine)
             if cursor.atStart():
                 self.setTextCursor(cursor)
                 event.accept()
-        elif key_sequence.matches(QtGui.QKeySequence(QtCore.Qt.Key_Down)):
-            cursor.movePosition(QtGui.QTextCursor.EndOfLine)
+        elif key_sequence.matches(QtGui.QKeySequence(QtCore.Qt.Key.Key_Down)):
+            cursor.movePosition(QtGui.QTextCursor.MoveOperation.EndOfLine)
             if cursor.atEnd():
                 self.setTextCursor(cursor)
                 event.accept()
 
-        elif self.auto_indent and \
-                key_sequence.matches(QtGui.QKeySequence(QtCore.Qt.Key_Return)):
+        elif self.auto_indent and key_sequence.matches(
+            QtGui.QKeySequence(QtCore.Qt.Key.Key_Return)
+        ):
             event.accept()
             return self.autoindent_newline()
         elif key_sequence.matches(self.indent_key):
@@ -403,44 +423,70 @@ class CodeWidget(QtGui.QPlainTextEdit):
         elif key_sequence.matches(self.comment_key):
             event.accept()
             return self.block_comment()
-        elif self.auto_indent and self.smart_backspace and \
-                key_sequence.matches(self.backspace_key) and \
-                self._backspace_should_unindent():
+        elif (
+            self.auto_indent
+            and self.smart_backspace
+            and key_sequence.matches(self.backspace_key)
+            and self._backspace_should_unindent()
+        ):
             event.accept()
             return self.block_unindent()
 
-        return super(CodeWidget, self).keyPressEvent(event)
+        return super().keyPressEvent(event)
 
     def resizeEvent(self, event):
         QtGui.QPlainTextEdit.resizeEvent(self, event)
         contents = self.contentsRect()
-        self.line_number_widget.setGeometry(QtCore.QRect(contents.left(),
-            contents.top(), self.line_number_widget.digits_width(),
-            contents.height()))
+        self.line_number_widget.setGeometry(
+            QtCore.QRect(
+                contents.left(),
+                contents.top(),
+                self.line_number_widget.digits_width(),
+                contents.height(),
+            )
+        )
 
         # use the viewport width to determine the right edge. This allows for
         # the propper placement w/ and w/o the scrollbar
-        right_pos = self.viewport().width() + self.line_number_widget.width() + 1\
-                    - self.status_widget.sizeHint().width()
-        self.status_widget.setGeometry(QtCore.QRect(right_pos,
-            contents.top(), self.status_widget.sizeHint().width(),
-            contents.height()))
+        right_pos = (
+            self.viewport().width()
+            + self.line_number_widget.width()
+            + 1
+            - self.status_widget.sizeHint().width()
+        )
+        self.status_widget.setGeometry(
+            QtCore.QRect(
+                right_pos,
+                contents.top(),
+                self.status_widget.sizeHint().width(),
+                contents.height(),
+            )
+        )
+
+    def focusOutEvent(self, event):
+        QtGui.QPlainTextEdit.focusOutEvent(self, event)
+        self.focus_lost.emit()
 
     def sizeHint(self):
         # Suggest a size that is 80 characters wide and 40 lines tall.
         style = self.style()
         opt = QtGui.QStyleOptionHeader()
         font_metrics = QtGui.QFontMetrics(self.document().defaultFont())
-        width = font_metrics.width(' ') * 80
+        # QFontMetrics.width() is deprecated and Qt docs suggest using
+        # horizontalAdvance() instead, but is only available since Qt 5.11
+        if QtCore.__version_info__ >= (5, 11):
+            width = font_metrics.horizontalAdvance(" ") * 80
+        else:
+            width = font_metrics.width(" ") * 80
         width += self.line_number_widget.sizeHint().width()
         width += self.status_widget.sizeHint().width()
-        width += style.pixelMetric(QtGui.QStyle.PM_ScrollBarExtent, opt, self)
+        width += style.pixelMetric(QtGui.QStyle.PixelMetric.PM_ScrollBarExtent, opt, self)
         height = font_metrics.height() * 40
         return QtCore.QSize(width, height)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private methods
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _get_indent_position(self, line):
         trimmed = line.rstrip()
@@ -456,30 +502,32 @@ class CodeWidget(QtGui.QPlainTextEdit):
         cursor = self.textCursor()
         cursor.clearSelection()
         cursor.setPosition(selected_blocks[0].position())
-        cursor.movePosition(QtGui.QTextCursor.StartOfBlock)
-        cursor.movePosition(QtGui.QTextCursor.NextBlock,
-                            QtGui.QTextCursor.KeepAnchor, len(selected_blocks))
-        cursor.movePosition(QtGui.QTextCursor.EndOfBlock,
-                            QtGui.QTextCursor.KeepAnchor)
+        cursor.movePosition(QtGui.QTextCursor.MoveOperation.StartOfBlock)
+        cursor.movePosition(
+            QtGui.QTextCursor.MoveOperation.NextBlock,
+            QtGui.QTextCursor.MoveMode.KeepAnchor,
+            len(selected_blocks),
+        )
+        cursor.movePosition(
+            QtGui.QTextCursor.MoveOperation.EndOfBlock, QtGui.QTextCursor.MoveMode.KeepAnchor
+        )
 
         self.setTextCursor(cursor)
 
     def _get_selected_blocks(self):
         cursor = self.textCursor()
         if cursor.position() > cursor.anchor():
-            move_op = QtGui.QTextCursor.PreviousBlock
             start_pos = cursor.anchor()
             end_pos = cursor.position()
         else:
-            move_op = QtGui.QTextCursor.NextBlock
             start_pos = cursor.position()
             end_pos = cursor.anchor()
 
         cursor.setPosition(start_pos)
-        cursor.movePosition(QtGui.QTextCursor.StartOfBlock)
+        cursor.movePosition(QtGui.QTextCursor.MoveOperation.StartOfBlock)
         blocks = [cursor.block()]
 
-        while cursor.movePosition(QtGui.QTextCursor.NextBlock):
+        while cursor.movePosition(QtGui.QTextCursor.MoveOperation.NextBlock):
             block = cursor.block()
             if block.position() < end_pos:
                 blocks.append(block)
@@ -505,12 +553,12 @@ class AdvancedCodeWidget(QtGui.QWidget):
         for search & replace
     """
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # AdvancedCodeWidget interface
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def __init__(self, parent, font=None, lexer=None):
-        super(AdvancedCodeWidget, self).__init__(parent)
+        super().__init__(parent)
 
         self.code = CodeWidget(self, font=font, lexer=lexer)
         self.find = FindWidget(self)
@@ -531,7 +579,8 @@ class AdvancedCodeWidget(QtGui.QWidget):
 
         self.replace.line_edit.returnPressed.connect(self.find_next)
         self.replace.line_edit.textChanged.connect(
-            self._update_replace_all_enabled)
+            self._update_replace_all_enabled
+        )
         self.replace.next_button.clicked.connect(self.find_next)
         self.replace.prev_button.clicked.connect(self.find_prev)
         self.replace.replace_button.clicked.connect(self.replace_next)
@@ -546,6 +595,24 @@ class AdvancedCodeWidget(QtGui.QWidget):
 
         self.setLayout(layout)
 
+    def _remove_event_listeners(self):
+        self.code.selectionChanged.disconnect(self._update_replace_enabled)
+
+        self.find.line_edit.returnPressed.disconnect(self.find_next)
+        self.find.next_button.clicked.disconnect(self.find_next)
+        self.find.prev_button.clicked.disconnect(self.find_prev)
+
+        self.replace.line_edit.returnPressed.disconnect(self.find_next)
+        self.replace.line_edit.textChanged.disconnect(
+            self._update_replace_all_enabled
+        )
+        self.replace.next_button.clicked.disconnect(self.find_next)
+        self.replace.prev_button.clicked.disconnect(self.find_prev)
+        self.replace.replace_button.clicked.disconnect(self.replace_next)
+        self.replace.replace_all_button.clicked.disconnect(self.replace_all)
+
+        self.code._remove_event_listeners()
+
     def lines(self):
         """ Return the number of lines.
         """
@@ -579,9 +646,10 @@ class AdvancedCodeWidget(QtGui.QWidget):
         self.replace.hide()
         self.find.show()
         self.find.setFocus()
-        if (self.active_find_widget == self.replace or
-            (not self.active_find_widget and
-             self.previous_find_widget == self.replace)):
+        if self.active_find_widget == self.replace or (
+            not self.active_find_widget
+            and self.previous_find_widget == self.replace
+        ):
             self.find.line_edit.setText(self.replace.line_edit.text())
         self.find.line_edit.selectAll()
         self.active_find_widget = self.find
@@ -590,14 +658,15 @@ class AdvancedCodeWidget(QtGui.QWidget):
         self.find.hide()
         self.replace.show()
         self.replace.setFocus()
-        if (self.active_find_widget == self.find or
-            (not self.active_find_widget and
-             self.previous_find_widget == self.find)):
+        if self.active_find_widget == self.find or (
+            not self.active_find_widget
+            and self.previous_find_widget == self.find
+        ):
             self.replace.line_edit.setText(self.find.line_edit.text())
         self.replace.line_edit.selectAll()
         self.active_find_widget = self.replace
 
-    def find_in_document(self, search_text, direction='forward', replace=None):
+    def find_in_document(self, search_text, direction="forward", replace=None):
         """ Finds the next occurance of the desired text and optionally
             replaces it. If 'replace' is None, a regular search will
             be executed, otherwise it will replace the occurance with
@@ -615,16 +684,18 @@ class AdvancedCodeWidget(QtGui.QWidget):
 
         flags = QtGui.QTextDocument.FindFlags(0)
         if self.active_find_widget.case_action.isChecked():
-            flags |= QtGui.QTextDocument.FindCaseSensitively
+            flags |= QtGui.QTextDocument.FindFlag.FindCaseSensitively
         if self.active_find_widget.word_action.isChecked():
-            flags |= QtGui.QTextDocument.FindWholeWords
-        if direction == 'backward':
-            flags |= QtGui.QTextDocument.FindBackward
+            flags |= QtGui.QTextDocument.FindFlag.FindWholeWords
+        if direction == "backward":
+            flags |= QtGui.QTextDocument.FindFlag.FindBackward
 
         find_cursor = document.find(search_text, self.code.textCursor(), flags)
         if find_cursor.isNull() and wrap:
-            if direction == 'backward':
-                find_cursor = document.find(search_text, document.characterCount()-1, flags)
+            if direction == "backward":
+                find_cursor = document.find(
+                    search_text, document.characterCount() - 1, flags
+                )
             else:
                 find_cursor = document.find(search_text, 0, flags)
 
@@ -635,21 +706,27 @@ class AdvancedCodeWidget(QtGui.QWidget):
                 find_cursor.insertText(replace)
                 find_cursor.endEditBlock()
                 find_cursor.movePosition(
-                    QtGui.QTextCursor.Left, QtGui.QTextCursor.MoveAnchor,len(replace))
+                    QtGui.QTextCursor.MoveOperation.Left,
+                    QtGui.QTextCursor.MoveMode.MoveAnchor,
+                    len(replace),
+                )
                 find_cursor.movePosition(
-                    QtGui.QTextCursor.Right, QtGui.QTextCursor.KeepAnchor,len(replace))
+                    QtGui.QTextCursor.MoveOperation.Right,
+                    QtGui.QTextCursor.MoveMode.KeepAnchor,
+                    len(replace),
+                )
                 self.code.setTextCursor(find_cursor)
             else:
                 self.code.setTextCursor(find_cursor)
             return find_cursor
         else:
-            #else not found: beep or indicate?
+            # else not found: beep or indicate?
             return None
 
     def find_next(self):
         if not self.active_find_widget:
             self.enable_find()
-        search_text = unicode(self.active_find_widget.line_edit.text())
+        search_text = str(self.active_find_widget.line_edit.text())
         cursor = self.find_in_document(search_text=search_text)
 
         if cursor:
@@ -659,9 +736,10 @@ class AdvancedCodeWidget(QtGui.QWidget):
     def find_prev(self):
         if not self.active_find_widget:
             self.enable_find()
-        search_text = unicode(self.active_find_widget.line_edit.text())
-        cursor = self.find_in_document(search_text=search_text,
-                                       direction='backward')
+        search_text = str(self.active_find_widget.line_edit.text())
+        cursor = self.find_in_document(
+            search_text=search_text, direction="backward"
+        )
         if cursor:
             return 1
         return 0
@@ -680,14 +758,17 @@ class AdvancedCodeWidget(QtGui.QWidget):
         return 0
 
     def replace_all(self):
-        search_text = unicode(self.replace.line_edit.text())
-        replace_text = unicode(self.replace.replace_edit.text())
+        search_text = str(self.replace.line_edit.text())
+        replace_text = str(self.replace.replace_edit.text())
 
         count = 0
         cursor = self.code.textCursor()
         cursor.beginEditBlock()
-        while self.find_in_document(search_text=search_text,
-                                    replace=replace_text) != None:
+        while (
+            self.find_in_document(
+                search_text=search_text, replace=replace_text
+            ) is not None
+        ):
             count += 1
         cursor.endEditBlock()
         return count
@@ -703,18 +784,18 @@ class AdvancedCodeWidget(QtGui.QWidget):
     def centerCursor(self):
         self.code.centerCursor()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # QWidget interface
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def keyPressEvent(self, event):
         key_sequence = QtGui.QKeySequence(event.key() + int(event.modifiers()))
-
-        if key_sequence.matches(QtGui.QKeySequence.Find):
+        if key_sequence.matches(QtGui.QKeySequence.StandardKey.Find):
             self.enable_find()
-        elif key_sequence.matches(QtGui.QKeySequence.Replace):
-            self.enable_replace()
-        elif key_sequence.matches(QtGui.QKeySequence(QtCore.Qt.Key_Escape)):
+        elif key_sequence.matches(QtGui.QKeySequence.StandardKey.Replace):
+            if not self.code.isReadOnly():
+                self.enable_replace()
+        elif key_sequence.matches(QtGui.QKeySequence(QtCore.Qt.Key.Key_Escape)):
             if self.active_find_widget:
                 self.find.hide()
                 self.replace.hide()
@@ -722,11 +803,11 @@ class AdvancedCodeWidget(QtGui.QWidget):
                 self.previous_find_widget = self.active_find_widget
                 self.active_find_widget = None
 
-        return super(AdvancedCodeWidget, self).keyPressEvent(event)
+        return super().keyPressEvent(event)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private methods
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _update_replace_enabled(self):
         selection = self.code.textCursor().selectedText()
@@ -737,26 +818,25 @@ class AdvancedCodeWidget(QtGui.QWidget):
         self.replace.replace_all_button.setEnabled(len(text))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     def set_trace():
         from PyQt4.QtCore import pyqtRemoveInputHook
+
         pyqtRemoveInputHook()
         import pdb
-        pdb.Pdb().set_trace(sys._getframe().f_back)
 
-    import sys
+        pdb.Pdb().set_trace(sys._getframe().f_back)
 
     app = QtGui.QApplication(sys.argv)
     window = AdvancedCodeWidget(None)
 
     if len(sys.argv) > 1:
-        f = open(sys.argv[1], 'r')
+        f = open(sys.argv[1], "r")
         window.code.setPlainText(f.read())
 
-    window.code.set_info_lines([3,4,8])
+    window.code.set_info_lines([3, 4, 8])
 
     window.resize(640, 640)
     window.show()
     sys.exit(app.exec_())
-
