@@ -1,27 +1,30 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2007, Riverbank Computing Limited
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+# (C) Copyright 2007 Riverbank Computing Limited
 # This software is provided without warranty under the terms of the BSD license.
 # However, when used with the GPL version of PyQt the additional terms described in the PyQt GPL exception also apply
 
-#
-# Author: Riverbank Computing Limited
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
 
-
-# Major package imports.
 from pyface.qt import QtCore, QtGui
 
-# Enthought library imports.
-from traits.api import Bool, Dict, Enum, Instance, provides, Unicode
 
-# Local imports.
-from pyface.i_confirmation_dialog import IConfirmationDialog, MConfirmationDialog
+from traits.api import Bool, Dict, Enum, provides, Str
+
+
+from pyface.i_confirmation_dialog import (
+    IConfirmationDialog,
+    MConfirmationDialog,
+)
 from pyface.constant import CANCEL, YES, NO
-from pyface.image_resource import ImageResource
-from dialog import Dialog, _RESULT_MAP
+from pyface.ui_traits import Image
+from .dialog import Dialog, _RESULT_MAP
 
 
 @provides(IConfirmationDialog)
@@ -30,43 +33,42 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
     IConfirmationDialog interface for the API documentation.
     """
 
-
-    #### 'IConfirmationDialog' interface ######################################
+    # 'IConfirmationDialog' interface -------------------------------------#
 
     cancel = Bool(False)
 
     default = Enum(NO, YES, CANCEL)
 
-    image = Instance(ImageResource)
+    image = Image()
 
-    message = Unicode
+    message = Str()
 
-    informative = Unicode
+    informative = Str()
 
-    detail = Unicode
+    detail = Str()
 
-    no_label = Unicode
+    no_label = Str()
 
-    yes_label = Unicode
+    yes_label = Str()
 
     # If we create custom buttons with the various roles, then we need to
     # keep track of the buttons so we can see what the user clicked.  It's
     # not correct nor sufficient to check the return result from QMessageBox.exec_().
     # (As of Qt 4.5.1, even clicking a button with the YesRole would lead to
-    # exec_() returning QDialog.Rejected.
+    # exec_() returning QDialog.DialogCode.Rejected.
     _button_result_map = Dict()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected 'IDialog' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _create_contents(self, parent):
         # In PyQt this is a canned dialog.
         pass
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected 'IWidget' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _create_control(self, parent):
         dlg = QtGui.QMessageBox(parent)
@@ -76,16 +78,22 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
         dlg.setInformativeText(self.informative)
         dlg.setDetailedText(self.detail)
 
+        if self.size != (-1, -1):
+            dlg.resize(*self.size)
+
+        if self.position != (-1, -1):
+            dlg.move(*self.position)
+
         if self.image is None:
-            dlg.setIcon(QtGui.QMessageBox.Warning)
+            dlg.setIcon(QtGui.QMessageBox.Icon.Warning)
         else:
             dlg.setIconPixmap(self.image.create_image())
 
         # The 'Yes' button.
         if self.yes_label:
-            btn = dlg.addButton(self.yes_label, QtGui.QMessageBox.YesRole)
+            btn = dlg.addButton(self.yes_label, QtGui.QMessageBox.ButtonRole.YesRole)
         else:
-            btn = dlg.addButton(QtGui.QMessageBox.Yes)
+            btn = dlg.addButton(QtGui.QMessageBox.StandardButton.Yes)
         self._button_result_map[btn] = YES
 
         if self.default == YES:
@@ -93,9 +101,9 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
 
         # The 'No' button.
         if self.no_label:
-            btn = dlg.addButton(self.no_label, QtGui.QMessageBox.NoRole)
+            btn = dlg.addButton(self.no_label, QtGui.QMessageBox.ButtonRole.NoRole)
         else:
-            btn = dlg.addButton(QtGui.QMessageBox.No)
+            btn = dlg.addButton(QtGui.QMessageBox.StandardButton.No)
         self._button_result_map[btn] = NO
 
         if self.default == NO:
@@ -104,9 +112,11 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
         # The 'Cancel' button.
         if self.cancel:
             if self.cancel_label:
-                btn = dlg.addButton(self.cancel_label, QtGui.QMessageBox.RejectRole)
+                btn = dlg.addButton(
+                    self.cancel_label, QtGui.QMessageBox.ButtonRole.RejectRole
+                )
             else:
-                btn = dlg.addButton(QtGui.QMessageBox.Cancel)
+                btn = dlg.addButton(QtGui.QMessageBox.StandardButton.Cancel)
 
             self._button_result_map[btn] = CANCEL
 
@@ -116,7 +126,7 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
         return dlg
 
     def _show_modal(self):
-        self.control.setWindowModality(QtCore.Qt.ApplicationModal)
+        self.control.setWindowModality(QtCore.Qt.WindowModality.ApplicationModal)
         retval = self.control.exec_()
         if self.control is None:
             # dialog window closed
@@ -130,5 +140,3 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
         else:
             retval = _RESULT_MAP[retval]
         return retval
-
-#### EOF ######################################################################
