@@ -1,19 +1,17 @@
-#  Copyright (c) 2011-18, Enthought, Inc.
-#  All rights reserved.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  Thanks for using Enthought open source!
-#
-#  Author: Enthought, Inc.
-# System library imports
+# Thanks for using Enthought open source!
+
 
 from pyface.qt import QtGui
 
-# Local imports
+
 from .console_widget import ConsoleWidget
 
 
@@ -22,21 +20,21 @@ class HistoryConsoleWidget(ConsoleWidget):
         executed and provides a readline-esque interface to this history.
     """
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
     # 'object' interface
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def __init__(self, *args, **kw):
-        super(HistoryConsoleWidget, self).__init__(*args, **kw)
+        super().__init__(*args, **kw)
 
         # HistoryConsoleWidget protected variables.
         self._history = []
         self._history_index = 0
-        self._history_prefix = ''
+        self._history_prefix = ""
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
     # 'ConsoleWidget' public interface
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def execute(self, source=None, hidden=False, interactive=False):
         """ Reimplemented to the store history.
@@ -44,8 +42,7 @@ class HistoryConsoleWidget(ConsoleWidget):
         if not hidden:
             history = self.input_buffer if source is None else source
 
-        executed = super(HistoryConsoleWidget, self).execute(
-            source, hidden, interactive)
+        executed = super().execute(source, hidden, interactive)
 
         if executed and not hidden:
             # Save the command unless it was an empty string or was identical
@@ -59,9 +56,9 @@ class HistoryConsoleWidget(ConsoleWidget):
 
         return executed
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
     # 'ConsoleWidget' abstract interface
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def _up_pressed(self):
         """ Called when the up key is pressed. Returns whether to continue
@@ -73,8 +70,9 @@ class HistoryConsoleWidget(ConsoleWidget):
             # Set a search prefix based on the cursor position.
             col = self._get_input_buffer_cursor_column()
             input_buffer = self.input_buffer
-            if self._history_index == len(self._history) or \
-                    (self._history_prefix and col != len(self._history_prefix)):
+            if self._history_index == len(self._history) or (
+                self._history_prefix and col != len(self._history_prefix)
+            ):
                 self._history_index = len(self._history)
                 self._history_prefix = input_buffer[:col]
 
@@ -86,10 +84,11 @@ class HistoryConsoleWidget(ConsoleWidget):
             # search.
             cursor = self._get_prompt_cursor()
             if self._history_prefix:
-                cursor.movePosition(QtGui.QTextCursor.Right,
-                                    n=len(self._history_prefix))
+                cursor.movePosition(
+                    QtGui.QTextCursor.MoveOperation.Right, n=len(self._history_prefix)
+                )
             else:
-                cursor.movePosition(QtGui.QTextCursor.EndOfLine)
+                cursor.movePosition(QtGui.QTextCursor.MoveOperation.EndOfLine)
             self._set_cursor(cursor)
 
             return False
@@ -112,19 +111,20 @@ class HistoryConsoleWidget(ConsoleWidget):
             # input buffer is set.)
             if self._history_prefix:
                 cursor = self._get_prompt_cursor()
-                cursor.movePosition(QtGui.QTextCursor.Right,
-                                    n=len(self._history_prefix))
+                cursor.movePosition(
+                    QtGui.QTextCursor.MoveOperation.Right, n=len(self._history_prefix)
+                )
                 self._set_cursor(cursor)
 
             return False
 
         return True
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
     # 'HistoryConsoleWidget' public interface
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
-    def history_previous(self, prefix=''):
+    def history_previous(self, prefix=""):
         """ If possible, set the input buffer to a previous item in the history.
 
         Parameters:
@@ -145,7 +145,7 @@ class HistoryConsoleWidget(ConsoleWidget):
             self._history_index = index
             self.input_buffer = history
 
-    def history_next(self, prefix=''):
+    def history_next(self, prefix=""):
         """ Set the input buffer to a subsequent item in the history, or to the
         original search prefix if there is no such item.
 
@@ -164,9 +164,9 @@ class HistoryConsoleWidget(ConsoleWidget):
             history = prefix
         self.input_buffer = history
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
     # 'HistoryConsoleWidget' protected interface
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def _set_history(self, history, history_index=None):
         """ Replace the current history with a sequence of history items.
