@@ -1,27 +1,27 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2007, Riverbank Computing Limited
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+# (C) Copyright 2007 Riverbank Computing Limited
 # This software is provided without warranty under the terms of the BSD license.
 # However, when used with the GPL version of PyQt the additional terms described in the PyQt GPL exception also apply
 
-#
-# Author: Riverbank Computing Limited
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
 
-
-# Standard library imports.
 import os
 
-# Major package imports.
+
 from pyface.qt import QtGui
 
-# Enthought library imports.
-from traits.api import Any, HasTraits, List, Property, provides
-from traits.api import Unicode
 
-# Local imports.
+from traits.api import Any, HasTraits, List, Property, provides
+from traits.api import Str
+
+
 from pyface.i_image_resource import IImageResource, MImageResource
 
 
@@ -31,23 +31,22 @@ class ImageResource(MImageResource, HasTraits):
     IImageResource interface for the API documentation.
     """
 
-
-    #### Private interface ####################################################
+    # Private interface ----------------------------------------------------
 
     # The resource manager reference for the image.
-    _ref = Any
+    _ref = Any()
 
-    #### 'ImageResource' interface ############################################
+    # 'ImageResource' interface --------------------------------------------
 
-    absolute_path = Property(Unicode)
+    absolute_path = Property(Str)
 
-    name = Unicode
+    name = Str()
 
-    search_path = List
+    search_path = List()
 
-    ###########################################################################
-    # 'ImageResource' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
+    # 'IImage' interface.
+    # ------------------------------------------------------------------------
 
     # Qt doesn't specifically require bitmaps anywhere so just use images.
     create_bitmap = MImageResource.create_image
@@ -62,9 +61,25 @@ class ImageResource(MImageResource, HasTraits):
 
         return QtGui.QIcon(image)
 
-    ###########################################################################
+    def image_size(cls, image):
+        """ Get the size of a toolkit image
+
+        Parameters
+        ----------
+        image : toolkit image
+            A toolkit image to compute the size of.
+
+        Returns
+        -------
+        size : tuple
+            The (width, height) tuple giving the size of the image.
+        """
+        size = image.size()
+        return (size.width(), size.height())
+
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _get_absolute_path(self):
         # FIXME: This doesn't quite work the new notion of image size. We
@@ -78,5 +93,3 @@ class ImageResource(MImageResource, HasTraits):
             absolute_path = self._get_image_not_found().absolute_path
 
         return absolute_path
-
-#### EOF ######################################################################
