@@ -1,21 +1,38 @@
-# Standard library imports.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 from itertools import combinations
 import logging
 
-# System library imports.
-from pyface.qt import QtCore, QtGui
 
-# Enthought library imports.
+from pyface.qt import QtCore, QtGui, is_qt4
+
+
 from traits.api import Any, HasTraits
 
-# Local imports.
-from dock_pane import AREA_MAP
-from pyface.tasks.task_layout import LayoutContainer, PaneItem, Tabbed, \
-     Splitter, HSplitter, VSplitter
+
+from pyface.tasks.task_layout import (
+    LayoutContainer,
+    PaneItem,
+    Tabbed,
+    Splitter,
+    HSplitter,
+    VSplitter,
+)
+from .dock_pane import AREA_MAP
 
 # Contants.
-ORIENTATION_MAP = { 'horizontal' : QtCore.Qt.Horizontal,
-                    'vertical': QtCore.Qt.Vertical }
+ORIENTATION_MAP = {
+    "horizontal": QtCore.Qt.Orientation.Horizontal,
+    "vertical": QtCore.Qt.Orientation.Vertical,
+}
 
 # Logging.
 logger = logging.getLogger(__name__)
@@ -25,19 +42,19 @@ class MainWindowLayout(HasTraits):
     """ A class for applying declarative layouts to a QMainWindow.
     """
 
-    #### 'MainWindowLayout' interface #########################################
+    # 'MainWindowLayout' interface -----------------------------------------
 
     # The QMainWindow control to lay out.
-    control = Any
+    control = Any()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'MainWindowLayout' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def get_layout(self, layout, include_sizes=True):
         """ Get the layout by adding sublayouts to the specified DockLayout.
         """
-        for name, q_dock_area in AREA_MAP.iteritems():
+        for name, q_dock_area in AREA_MAP.items():
             sublayout = self.get_layout_for_area(q_dock_area, include_sizes)
             setattr(layout, name, sublayout)
 
@@ -50,13 +67,20 @@ class MainWindowLayout(HasTraits):
         for child in self.control.children():
             # Iterate through *visibile* dock widgets. (Inactive tabbed dock
             # widgets are "visible" but have invalid positions.)
-            if isinstance(child, QtGui.QDockWidget) and child.isVisible() and \
-                   self.control.dockWidgetArea(child) == q_dock_area and \
-                   child.x() >= 0 and child.y() >= 0:
+            if (
+                isinstance(child, QtGui.QDockWidget)
+                and child.isVisible()
+                and self.control.dockWidgetArea(child) == q_dock_area
+                and child.x() >= 0
+                and child.y() >= 0
+            ):
                 # Get the list of dock widgets in this tab group in order.
                 geometry = child.geometry()
-                tabs = [ tab for tab in self.control.tabifiedDockWidgets(child)
-                         if tab.isVisible() ]
+                tabs = [
+                    tab
+                    for tab in self.control.tabifiedDockWidgets(child)
+                    if tab.isVisible()
+                ]
                 if tabs:
                     tab_bar = self._get_tab_bar(child)
                     tab_index = tab_bar.currentIndex()
@@ -65,8 +89,10 @@ class MainWindowLayout(HasTraits):
 
                 # Create the leaf-level item for the child.
                 if tabs:
-                    panes = [ self._prepare_pane(dock_widget, include_sizes)
-                              for dock_widget in tabs ]
+                    panes = [
+                        self._prepare_pane(dock_widget, include_sizes)
+                        for dock_widget in tabs
+                    ]
                     item = Tabbed(*panes, active_tab=panes[tab_index].id)
                 else:
                     item = self._prepare_pane(child, include_sizes)
@@ -81,12 +107,12 @@ class MainWindowLayout(HasTraits):
                 if item1 not in remove and item2 not in remove:
                     rect1, rect2 = rects[item1], rects[item2]
                     orient = self._get_division_orientation(rect1, rect2, True)
-                    if orient == QtCore.Qt.Horizontal:
+                    if orient == QtCore.Qt.Orientation.Horizontal:
                         if rect1.y() < rect2.y():
                             item = VSplitter(item1, item2)
                         else:
                             item = VSplitter(item2, item1)
-                    elif orient == QtCore.Qt.Vertical:
+                    elif orient == QtCore.Qt.Orientation.Vertical:
                         if rect1.x() < rect2.x():
                             item = HSplitter(item1, item2)
                         else:
@@ -102,7 +128,9 @@ class MainWindowLayout(HasTraits):
                 items.difference_update(remove)
             else:
                 # Raise an exception instead of falling into an infinite loop.
-                raise RuntimeError('Unable to extract layout from QMainWindow.')
+                raise RuntimeError(
+                    "Unable to extract layout from QMainWindow."
+                )
 
         if items:
             return items.pop()
@@ -119,17 +147,20 @@ class MainWindowLayout(HasTraits):
 
         # Perform the layout. This will assign fixed sizes to the dock widgets
         # to enforce size constraints specified in the PaneItems.
-        for name, q_dock_area in AREA_MAP.iteritems():
+        for name, q_dock_area in AREA_MAP.items():
             sublayout = getattr(layout, name)
             if sublayout:
-                self.set_layout_for_area(sublayout, q_dock_area,
-                                         _toplevel_call=False)
+                self.set_layout_for_area(
+                    sublayout, q_dock_area, _toplevel_call=False
+                )
 
-        # Remove the fixed sizes once Qt activates the layout.
-        QtCore.QTimer.singleShot(0, self._reset_fixed_sizes)
+        if is_qt4:
+            # Remove the fixed sizes once Qt activates the layout.
+            QtCore.QTimer.singleShot(0, self._reset_fixed_sizes)
 
-    def set_layout_for_area(self, layout, q_dock_area,
-                            _toplevel_added=False, _toplevel_call=True):
+    def set_layout_for_area(
+        self, layout, q_dock_area, _toplevel_added=False, _toplevel_call=True
+    ):
         """ Applies a LayoutItem to the specified dock area.
         """
         # If we try to do the layout bottom-up, Qt will become confused. In
@@ -187,33 +218,38 @@ class MainWindowLayout(HasTraits):
 
             # Now we can recurse.
             for i, item in enumerate(layout.items):
-                self.set_layout_for_area(item, q_dock_area,
-                    _toplevel_added=True, _toplevel_call=False)
+                self.set_layout_for_area(
+                    item,
+                    q_dock_area,
+                    _toplevel_added=True,
+                    _toplevel_call=False,
+                )
 
         else:
             raise MainWindowLayoutError("Unknown layout item %r" % layout)
 
-        # Remove the fixed sizes once Qt activates the layout.
-        if _toplevel_call:
-            QtCore.QTimer.singleShot(0, self._reset_fixed_sizes)
+        if is_qt4:
+            # Remove the fixed sizes once Qt activates the layout.
+            if _toplevel_call:
+                QtCore.QTimer.singleShot(0, self._reset_fixed_sizes)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'MainWindowLayout' abstract interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _get_dock_widget(self, pane):
         """ Returns the QDockWidget associated with a PaneItem.
         """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _get_pane(self, dock_widget):
         """ Returns a PaneItem for a QDockWidget.
         """
-        raise NotImplementedError
+        raise NotImplementedError()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _get_division_orientation(self, one, two, splitter=False):
         """ Returns whether there is a division between two visible QWidgets.
@@ -224,16 +260,23 @@ class MainWindowLayout(HasTraits):
         united = one.united(two)
         if splitter:
             sep = self.control.style().pixelMetric(
-                QtGui.QStyle.PM_DockWidgetSeparatorExtent, None, self.control)
+                QtGui.QStyle.PixelMetric.PM_DockWidgetSeparatorExtent, None, self.control
+            )
             united.adjust(0, 0, -sep, -sep)
 
-        if one.x() == two.x() and one.width() == two.width() and \
-               united.height() == one.height() + two.height():
-            return QtCore.Qt.Horizontal
+        if (
+            one.x() == two.x()
+            and one.width() == two.width()
+            and united.height() == one.height() + two.height()
+        ):
+            return QtCore.Qt.Orientation.Horizontal
 
-        elif one.y() == two.y() and one.height() == two.height() and \
-                 united.width() == one.width() + two.width():
-            return QtCore.Qt.Vertical
+        elif (
+            one.y() == two.y()
+            and one.height() == two.height()
+            and united.width() == one.width() + two.width()
+        ):
+            return QtCore.Qt.Orientation.Vertical
 
         return 0
 
@@ -264,13 +307,18 @@ class MainWindowLayout(HasTraits):
         if isinstance(layout, PaneItem):
             dock_widget = self._get_dock_widget(layout)
             if dock_widget is None:
-                logger.warning('Cannot retrieve dock widget for pane %r'
-                               % layout.id)
+                logger.warning(
+                    "Cannot retrieve dock widget for pane %r" % layout.id
+                )
             else:
-                if layout.width > 0:
-                    dock_widget.widget().setFixedWidth(layout.width)
-                if layout.height > 0:
-                    dock_widget.widget().setFixedHeight(layout.height)
+                if is_qt4:
+                    if layout.width > 0:
+                        dock_widget.widget().setFixedWidth(layout.width)
+                    if layout.height > 0:
+                        dock_widget.widget().setFixedHeight(layout.height)
+                else:
+                    sizeHint = lambda: QtCore.QSize(layout.width, layout.height)
+                    dock_widget.widget().sizeHint = sizeHint
             return dock_widget
 
         elif isinstance(layout, LayoutContainer):
@@ -284,7 +332,7 @@ class MainWindowLayout(HasTraits):
         """
         if self.control is None:
             return
-        QWIDGETSIZE_MAX = (1 << 24) - 1 # Not exposed by Qt bindings.
+        QWIDGETSIZE_MAX = (1 << 24) - 1  # Not exposed by Qt bindings.
         for child in self.control.children():
             if isinstance(child, QtGui.QDockWidget):
                 child.widget().setMaximumSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX)
@@ -295,9 +343,9 @@ class MainWindowLayout(HasTraits):
                 child.setMinimumSize(0, 0)
 
 
-
 class MainWindowLayoutError(ValueError):
     """ Exception raised when a malformed LayoutItem is passed to the
     MainWindowLayout.
     """
+
     pass
