@@ -1,12 +1,21 @@
-# Enthought library imports.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 from pyface.tasks.i_task_pane import ITaskPane, MTaskPane
 from traits.api import provides
 
-# System library imports.
+
 from pyface.qt import QtGui
 
-# Local imports.
-from util import set_focus
+
+from .util import set_focus
 
 
 @provides(ITaskPane)
@@ -16,10 +25,9 @@ class TaskPane(MTaskPane):
     See the ITaskPane interface for API documentation.
     """
 
-
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'ITaskPane' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def create(self, parent):
         """ Create and set the toolkit-specific control that represents the
