@@ -1,15 +1,16 @@
-# Copyright (c) 2013 by Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 
 """ Tools for testing. """
 
-from __future__ import print_function
+
 from contextlib import contextmanager
 import os
 import sys
@@ -40,7 +41,7 @@ def delete_widget(widget, timeout=1.0):
 
     timer = QTimer()
     timer.setSingleShot(True)
-    timer.setInterval(timeout*1000)
+    timer.setInterval(round(timeout * 1000))
     timer.timeout.connect(app.quit)
     widget.destroyed.connect(app.quit)
 
@@ -51,7 +52,7 @@ def delete_widget(widget, timeout=1.0):
 
     if not timer.isActive():
         # We exited the event loop on timeout.
-        msg = 'Could not destroy widget before timeout: {!r}'
+        msg = "Could not destroy widget before timeout: {!r}"
         raise AssertionError(msg.format(widget))
 
 
@@ -60,7 +61,7 @@ def _convert_none_to_null_handle(stream):
     """ If 'stream' is None, provide a temporary handle to /dev/null. """
 
     if stream is None:
-        out = open(os.devnull, 'w')
+        out = open(os.devnull, "w")
         try:
             yield out
         finally:
@@ -105,7 +106,7 @@ def print_qt_widget_tree(widget, level=0):
     level = level + 4
     if level == 0:
         print()
-    print(' '*level, widget)
+    print(" " * level, widget)
     for child in widget.children():
         print_qt_widget_tree(child, level=level)
     if level == 0:
