@@ -1,24 +1,30 @@
-# Copyright (c) 2007, Riverbank Computing Limited
-# Copyright (c) 2017-18, Enthought, Inc.
+# (C) Copyright 2007 Riverbank Computing Limited
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license. However, when used with the GPL version of PyQt the additional
-# terms described in the PyQt GPL exception also apply
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-# Author: Riverbank Computing Limited
-# Author: Enhtought, Inc.
-# Description: <Enthought pyface package component>
+# Thanks for using Enthought open source!
+
+import weakref
 
-# Major package imports.
 from pyface.qt import QtCore, QtGui
 
-# Enthought library imports.
+
 from traits.api import (
-    Enum, Event, Property, Tuple, Unicode, VetoableEvent, provides
+    Enum,
+    Event,
+    Property,
+    Tuple,
+    Str,
+    VetoableEvent,
+    provides,
 )
 
-# Local imports.
+
 from pyface.i_window import IWindow, MWindow
 from pyface.key_pressed_event import KeyPressedEvent
 from .gui import GUI
@@ -37,29 +43,29 @@ class Window(MWindow, Widget):
 
     size = Property(Tuple)
 
-    size_state = Enum('normal', 'maximized')
+    size_state = Enum("normal", "maximized")
 
-    title = Unicode
+    title = Str()
 
     # Window Events ----------------------------------------------------------
 
     #: The window has been opened.
-    opened = Event
+    opened = Event()
 
     #: The window is about to open.
-    opening = VetoableEvent
+    opening = VetoableEvent()
 
     #: The window has been activated.
-    activated = Event
+    activated = Event()
 
     #: The window has been closed.
-    closed = Event
+    closed = Event()
 
     #: The window is about to be closed.
-    closing = VetoableEvent
+    closing = VetoableEvent()
 
     #: The window has been deactivated.
-    deactivated = Event
+    deactivated = Event()
 
     # Private interface ------------------------------------------------------
 
@@ -91,7 +97,7 @@ class Window(MWindow, Widget):
             control.resize(*self.size)
         if self.position != (-1, -1):
             control.move(*self.position)
-        if self.size_state != 'normal':
+        if self.size_state != "normal":
             self._size_state_changed(self.size_state)
         control.setWindowTitle(self.title)
         control.setEnabled(self.enabled)
@@ -106,7 +112,6 @@ class Window(MWindow, Widget):
     # -------------------------------------------------------------------------
 
     def destroy(self):
-        self._remove_event_listeners()
 
         if self.control is not None:
             # Avoid problems with recursive calls.
@@ -120,7 +125,7 @@ class Window(MWindow, Widget):
             # hides it), but the close may trigger an application shutdown,
             # which can take a long time and may also attempt to recursively
             # destroy the window again.
-            super(Window, self).destroy()
+            super().destroy()
             control.close()
 
     # -------------------------------------------------------------------------
@@ -141,7 +146,7 @@ class Window(MWindow, Widget):
         old = self._position
         self._position = position
 
-        self.trait_property_changed('position', old, position)
+        self.trait_property_changed("position", old, position)
 
     def _get_size(self):
         """ Property getter for size. """
@@ -157,20 +162,20 @@ class Window(MWindow, Widget):
         old = self._size
         self._size = size
 
-        self.trait_property_changed('size', old, size)
+        self.trait_property_changed("size", old, size)
 
     def _size_state_changed(self, state):
         control = self.control
         if control is None:
             return  # Nothing to do here
 
-        if state == 'maximized':
+        if state == "maximized":
             control.setWindowState(
-                control.windowState() | QtCore.Qt.WindowMaximized
+                control.windowState() | QtCore.Qt.WindowState.WindowMaximized
             )
-        elif state == 'normal':
+        elif state == "normal":
             control.setWindowState(
-                control.windowState() & ~QtCore.Qt.WindowMaximized
+                control.windowState() & ~QtCore.Qt.WindowState.WindowMaximized
             )
 
     def _title_changed(self, title):
@@ -191,20 +196,22 @@ class WindowEventFilter(QtCore.QObject):
     def __init__(self, window):
         """ Initialise the event filter. """
         QtCore.QObject.__init__(self)
-        self._window = window
+        # use a weakref to fix finalization issues with circular references
+        # we don't want to be the last thing holding a reference to the window
+        self._window = weakref.ref(window)
 
     def eventFilter(self, obj, e):
         """ Adds any event listeners required by the window. """
 
-        window = self._window
+        window = self._window()
 
         # Sanity check.
-        if obj is not window.control:
+        if window is None or obj is not window.control:
             return False
 
         typ = e.type()
 
-        if typ == QtCore.QEvent.Close:
+        if typ == QtCore.QEvent.Type.Close:
             # Do not destroy the window during its event handler.
             GUI.invoke_later(window.close)
 
@@ -213,30 +220,30 @@ class WindowEventFilter(QtCore.QObject):
 
             return True
 
-        if typ == QtCore.QEvent.WindowActivate:
+        if typ == QtCore.QEvent.Type.WindowActivate:
             window.activated = window
 
-        elif typ == QtCore.QEvent.WindowDeactivate:
+        elif typ == QtCore.QEvent.Type.WindowDeactivate:
             window.deactivated = window
 
-        elif typ in {QtCore.QEvent.Show, QtCore.QEvent.Hide}:
+        elif typ in {QtCore.QEvent.Type.Show, QtCore.QEvent.Type.Hide}:
             window.visible = window.control.isVisible()
 
-        elif typ == QtCore.QEvent.Resize:
+        elif typ == QtCore.QEvent.Type.Resize:
             # Get the new size and set the shadow trait without performing
             # notification.
             size = e.size()
             window._size = (size.width(), size.height())
 
-        elif typ == QtCore.QEvent.Move:
+        elif typ == QtCore.QEvent.Type.Move:
             # Get the real position and set the trait without performing
             # notification. Don't use event.pos(), as this excludes the window
             # frame geometry.
             pos = window.control.pos()
             window._position = (pos.x(), pos.y())
 
-        elif typ == QtCore.QEvent.KeyPress:
-            # Pyface doesn't seem to be Unicode aware.  Only keep the key code
+        elif typ == QtCore.QEvent.Type.KeyPress:
+            # Pyface doesn't seem to be Str aware.  Only keep the key code
             # if it corresponds to a single Latin1 character.
             kstr = e.text()
             try:
@@ -246,22 +253,26 @@ class WindowEventFilter(QtCore.QObject):
 
             mods = e.modifiers()
             window.key_pressed = KeyPressedEvent(
-                alt_down=((mods &
-                           QtCore.Qt.AltModifier) == QtCore.Qt.AltModifier),
-                control_down=((mods & QtCore.Qt.ControlModifier
-                               ) == QtCore.Qt.ControlModifier),
-                shift_down=((mods & QtCore.Qt.ShiftModifier
-                             ) == QtCore.Qt.ShiftModifier),
+                alt_down=(
+                    (mods & QtCore.Qt.KeyboardModifier.AltModifier) == QtCore.Qt.KeyboardModifier.AltModifier
+                ),
+                control_down=(
+                    (mods & QtCore.Qt.KeyboardModifier.ControlModifier)
+                    == QtCore.Qt.KeyboardModifier.ControlModifier
+                ),
+                shift_down=(
+                    (mods & QtCore.Qt.KeyboardModifier.ShiftModifier) == QtCore.Qt.KeyboardModifier.ShiftModifier
+                ),
                 key_code=kcode,
-                event=e
+                event=e,
             )
 
-        elif typ == QtCore.QEvent.WindowStateChange:
+        elif typ == QtCore.QEvent.Type.WindowStateChange:
             # set the size_state of the window.
             state = obj.windowState()
-            if state & QtCore.Qt.WindowMaximized:
-                window.size_state = 'maximized'
+            if state & QtCore.Qt.WindowState.WindowMaximized:
+                window.size_state = "maximized"
             else:
-                window.size_state = 'normal'
+                window.size_state = "normal"
 
         return False
