@@ -1,16 +1,24 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2008, Riverbank Computing Limited
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+# (C) Copyright 2008 Riverbank Computing Limited
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD license.
 # However, when used with the GPL version of PyQt the additional terms described in the PyQt GPL exception also apply
 
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
-# Standard library imports.
 import sys
 
-# Major library imports.
+
 from pyface.qt import QtCore, QtGui, qt_api
 
 from pyface.image_resource import ImageResource
@@ -26,11 +34,13 @@ class SplitTabWidget(QtGui.QSplitter):
     new_window_request = QtCore.Signal(QtCore.QPoint, QtGui.QWidget)
     tab_close_request = QtCore.Signal(QtGui.QWidget)
     tab_window_changed = QtCore.Signal(QtGui.QWidget)
+    editor_has_focus = QtCore.Signal(QtGui.QWidget)
+    focus_changed = QtCore.Signal(QtGui.QWidget, QtGui.QWidget)
 
     # The different hotspots of a QTabWidget.  An non-negative value is a tab
     # index and the hotspot is to the left of it.
 
-    tabTextChanged = QtCore.Signal(QtGui.QWidget, unicode)
+    tabTextChanged = QtCore.Signal(QtGui.QWidget, str)
     _HS_NONE = -1
     _HS_AFTER_LAST_TAB = -2
     _HS_NORTH = -3
@@ -46,9 +56,7 @@ class SplitTabWidget(QtGui.QSplitter):
 
         self.clear()
 
-        QtCore.QObject.connect(QtGui.QApplication.instance(),
-                QtCore.SIGNAL('focusChanged(QWidget *,QWidget *)'),
-                self._focus_changed)
+        QtGui.QApplication.instance().focusChanged.connect(self._focus_changed)
 
     def clear(self):
         """ Restore the widget to its pristine state. """
@@ -92,8 +100,8 @@ class SplitTabWidget(QtGui.QSplitter):
                 for t in range(ch.count()):
                     # A tab state is a tuple of the widget's object name and
                     # the title.
-                    name = unicode(ch.widget(t).objectName())
-                    title = unicode(ch.tabText(t))
+                    name = str(ch.widget(t).objectName())
+                    title = str(ch.tabText(t))
 
                     tab_states.append((name, title))
 
@@ -104,7 +112,7 @@ class SplitTabWidget(QtGui.QSplitter):
 
             sp_ch_states.append(ch_state)
 
-        return (str(QtGui.QSplitter.saveState(qsplitter)), sp_ch_states)
+        return (QtGui.QSplitter.saveState(qsplitter).data(), sp_ch_states)
 
     def restoreState(self, state, factory):
         """ Restore the contents from the given state (returned by a previous
@@ -177,7 +185,7 @@ class SplitTabWidget(QtGui.QSplitter):
             ch = _TabWidget(self)
             self.addWidget(ch)
 
-        idx = ch.insertTab(self._current_tab_idx+1, w, text)
+        idx = ch.insertTab(self._current_tab_idx + 1, w, text)
 
         # If the tab has been added to the current tab widget then make it the
         # current tab.
@@ -272,11 +280,13 @@ class SplitTabWidget(QtGui.QSplitter):
                 nfw = fw.nextInFocusChain()
 
                 while nfw is not fw:
-                    if nfw.focusPolicy() & QtCore.Qt.TabFocus and \
-                       nfw.focusProxy() is None and \
-                       nfw.isVisibleTo(w) and \
-                       nfw.isEnabled() and \
-                       w.isAncestorOf(nfw):
+                    if (
+                        nfw.focusPolicy() & QtCore.Qt.FocusPolicy.TabFocus
+                        and nfw.focusProxy() is None
+                        and nfw.isVisibleTo(w)
+                        and nfw.isEnabled()
+                        and w.isAncestorOf(nfw)
+                    ):
                         break
 
                     nfw = nfw.nextInFocusChain()
@@ -292,14 +302,14 @@ class SplitTabWidget(QtGui.QSplitter):
         # It is possible for the C++ layer of this object to be deleted between
         # the time when the focus change signal is emitted and time when the
         # slots are dispatched by the Qt event loop. This may be a bug in PyQt4.
-        if qt_api == 'pyqt':
+        if qt_api == "pyqt":
             import sip
+
             if sip.isdeleted(self):
                 return
 
         if self._repeat_focus_changes:
-            self.emit(QtCore.SIGNAL('focusChanged(QWidget *,QWidget *)'),
-                      old, new)
+            self.focus_changed.emit(old, new)
 
         if new is None:
             return
@@ -321,7 +331,7 @@ class SplitTabWidget(QtGui.QSplitter):
             else:
                 nw = ntw.widget(ntidx)
 
-            self.emit(QtCore.SIGNAL('hasFocus'), nw)
+            self.editor_has_focus.emit(nw)
 
     def _tab_widget_of(self, target):
         """ Return the tab widget and index of the widget that contains the
@@ -394,8 +404,9 @@ class SplitTabWidget(QtGui.QSplitter):
                     self._rband.deleteLater()
                 position = QtCore.QPoint(*hs_geom[0:2])
                 window = tw.window()
-                self._rband = QtGui.QRubberBand(QtGui.QRubberBand.Rectangle,
-                                                window)
+                self._rband = QtGui.QRubberBand(
+                    QtGui.QRubberBand.Shape.Rectangle, window
+                )
                 self._rband.move(window.mapFromGlobal(position))
                 self._rband.resize(*hs_geom[2:4])
                 self._rband.show()
@@ -423,8 +434,8 @@ class SplitTabWidget(QtGui.QSplitter):
         if dhs == self._HS_OUTSIDE:
             # Disable tab tear-out for now. It works, but this is something that
             # should be turned on manually. We need an interface for this.
-            #ticon, ttext, ttextcolor, tbuttn, twidg = self._remove_tab(stab_w, stab)
-            #self.new_window_request.emit(pos, twidg)
+            # ticon, ttext, ttextcolor, tbuttn, twidg = self._remove_tab(stab_w, stab)
+            # self.new_window_request.emit(pos, twidg)
             return
 
         # See if the tab is being moved to an existing tab widget.
@@ -434,12 +445,17 @@ class SplitTabWidget(QtGui.QSplitter):
                 if stab == dhs:
                     return
 
-                if dhs == self._HS_AFTER_LAST_TAB and stab == stab_w.count()-1:
+                if (
+                    dhs == self._HS_AFTER_LAST_TAB
+                    and stab == stab_w.count() - 1
+                ):
                     return
 
             QtGui.QApplication.instance().blockSignals(True)
 
-            ticon, ttext, ttextcolor, tbuttn, twidg = self._remove_tab(stab_w, stab)
+            ticon, ttext, ttextcolor, tbuttn, twidg = self._remove_tab(
+                stab_w, stab
+            )
 
             if dhs == self._HS_AFTER_LAST_TAB:
                 idx = dtab_w.addTab(twidg, ticon, ttext)
@@ -458,7 +474,7 @@ class SplitTabWidget(QtGui.QSplitter):
                 idx = dtab_w.insertTab(dhs, twidg, ticon, ttext)
                 dtab_w.tabBar().setTabTextColor(idx, ttextcolor)
 
-            if (tbuttn):
+            if tbuttn:
                 dtab_w.show_button(idx)
             dsplit_w._set_current_tab(dtab_w, idx)
 
@@ -471,7 +487,9 @@ class SplitTabWidget(QtGui.QSplitter):
 
             # Remove the tab from its current tab widget and create a new one
             # for it.
-            ticon, ttext, ttextcolor, tbuttn, twidg = self._remove_tab(stab_w, stab)
+            ticon, ttext, ttextcolor, tbuttn, twidg = self._remove_tab(
+                stab_w, stab
+            )
             new_tw = _TabWidget(dsplit_w)
             idx = new_tw.addTab(twidg, ticon, ttext)
             new_tw.tabBar().setTabTextColor(0, ttextcolor)
@@ -483,7 +501,9 @@ class SplitTabWidget(QtGui.QSplitter):
             dspl_idx = dspl.indexOf(dtab_w)
 
             if dhs in (self._HS_NORTH, self._HS_SOUTH):
-                dspl, dspl_idx = dsplit_w._horizontal_split(dspl, dspl_idx, dhs)
+                dspl, dspl_idx = dsplit_w._horizontal_split(
+                    dspl, dspl_idx, dhs
+                )
             else:
                 dspl, dspl_idx = dsplit_w._vertical_split(dspl, dspl_idx, dhs)
 
@@ -505,18 +525,18 @@ class SplitTabWidget(QtGui.QSplitter):
         should be put.
         """
 
-        if spl.orientation() == QtCore.Qt.Vertical:
+        if spl.orientation() == QtCore.Qt.Orientation.Vertical:
             if hs == self._HS_SOUTH:
                 idx += 1
         elif spl is self and spl.count() == 1:
             # The splitter is the root and only has one child so we can just
             # change its orientation.
-            spl.setOrientation(QtCore.Qt.Vertical)
+            spl.setOrientation(QtCore.Qt.Orientation.Vertical)
 
             if hs == self._HS_SOUTH:
                 idx = -1
         else:
-            new_spl = QtGui.QSplitter(QtCore.Qt.Vertical)
+            new_spl = QtGui.QSplitter(QtCore.Qt.Orientation.Vertical)
             new_spl.addWidget(spl.widget(idx))
             spl.insertWidget(idx, new_spl)
 
@@ -534,18 +554,18 @@ class SplitTabWidget(QtGui.QSplitter):
         should be put.
         """
 
-        if spl.orientation() == QtCore.Qt.Horizontal:
+        if spl.orientation() == QtCore.Qt.Orientation.Horizontal:
             if hs == self._HS_EAST:
                 idx += 1
         elif spl is self and spl.count() == 1:
             # The splitter is the root and only has one child so we can just
             # change its orientation.
-            spl.setOrientation(QtCore.Qt.Horizontal)
+            spl.setOrientation(QtCore.Qt.Orientation.Horizontal)
 
             if hs == self._HS_EAST:
                 idx = -1
         else:
-            new_spl = QtGui.QSplitter(QtCore.Qt.Horizontal)
+            new_spl = QtGui.QSplitter(QtCore.Qt.Orientation.Horizontal)
             new_spl.addWidget(spl.widget(idx))
             spl.insertWidget(idx, new_spl)
 
@@ -566,7 +586,7 @@ class SplitTabWidget(QtGui.QSplitter):
         icon = tab_w.tabIcon(tab)
         text = tab_w.tabText(tab)
         text_color = tab_w.tabBar().tabTextColor(tab)
-        button = tab_w.tabBar().tabButton(tab, QtGui.QTabBar.LeftSide)
+        button = tab_w.tabBar().tabButton(tab, QtGui.QTabBar.ButtonPosition.LeftSide)
         w = tab_w.widget(tab)
         tab_w.removeTab(tab)
 
@@ -593,11 +613,14 @@ class SplitTabWidget(QtGui.QSplitter):
             for split_widget in top_widget.findChildren(SplitTabWidget, None):
                 visible_region = split_widget.visibleRegion()
                 widget_pos = split_widget.mapFromGlobal(global_pos)
-                if cloned_rect and split_widget.geometry().contains(widget_pos):
+                if cloned_rect and split_widget.geometry().contains(
+                    widget_pos
+                ):
                     visible_rect = visible_region.boundingRect()
                     widget_rect = QtCore.QRect(
                         split_widget.mapFromGlobal(cloned_rect.topLeft()),
-                        split_widget.mapFromGlobal(cloned_rect.bottomRight()))
+                        split_widget.mapFromGlobal(cloned_rect.bottomRight()),
+                    )
                     if not visible_rect.intersected(widget_rect).isEmpty():
                         break
                 elif visible_region.contains(widget_pos):
@@ -649,21 +672,31 @@ class SplitTabWidget(QtGui.QSplitter):
                     return (tw, self._HS_NORTH, (gx, gy, w, h / 4))
 
                 if y >= (3 * h) / 4:
-                    return (tw, self._HS_SOUTH, (gx, gy + (3*h) / 4, w, h / 4))
+                    return (
+                        tw,
+                        self._HS_SOUTH,
+                        (gx, gy + (3 * h) / 4, w, h / 4),
+                    )
 
                 if x < w / 4:
                     return (tw, self._HS_WEST, (gx, gy, w / 4, h))
 
                 if x >= (3 * w) / 4:
-                    return (tw, self._HS_EAST, (gx + (3*w) / 4, gy, w / 4, h))
+                    return (
+                        tw,
+                        self._HS_EAST,
+                        (gx + (3 * w) / 4, gy, w / 4, h),
+                    )
 
                 return miss
 
         # See if the hotspot is in the tab area.
         tpos = tw.mapFrom(split_widget, pos)
         tab_bar = tw.tabBar()
-        top_bottom = tw.tabPosition() in (QtGui.QTabWidget.North,
-                                          QtGui.QTabWidget.South)
+        top_bottom = tw.tabPosition() in (
+            QtGui.QTabWidget.TabPosition.North,
+            QtGui.QTabWidget.TabPosition.South,
+        )
         for i in range(tw.count()):
             rect = tab_bar.tabRect(i)
 
@@ -708,13 +741,17 @@ class SplitTabWidget(QtGui.QSplitter):
                 w = rect.width()
                 h = rect.height()
                 if top_bottom:
-                    tab_widths = sum(tab_bar.tabRect(i).width()
-                        for i in range(tab_bar.count()))
+                    tab_widths = sum(
+                        tab_bar.tabRect(i).width()
+                        for i in range(tab_bar.count())
+                    )
                     w -= tab_widths
                     gx += tab_widths
                 else:
-                    tab_heights = sum(tab_bar.tabRect(i).height()
-                        for i in range(tab_bar.count()))
+                    tab_heights = sum(
+                        tab_bar.tabRect(i).height()
+                        for i in range(tab_bar.count())
+                    )
                     h -= tab_heights
                     gy -= tab_heights
                 return (tw, self._HS_AFTER_LAST_TAB, (gx, gy, w, h))
@@ -732,6 +769,7 @@ inactive_style = """QTabWidget::pane { /* The tab widget frame */
  }
 """
 
+
 class _TabWidget(QtGui.QTabWidget):
     """ The _TabWidget class is a QTabWidget with a dragable tab bar. """
 
@@ -746,9 +784,9 @@ class _TabWidget(QtGui.QTabWidget):
         QtGui.QTabWidget.__init__(self, *args)
 
         # XXX this requires Qt > 4.5
-        if sys.platform == 'darwin':
+        if sys.platform == "darwin":
             self.setDocumentMode(True)
-        #self.setStyleSheet(inactive_style)
+        # self.setStyleSheet(inactive_style)
 
         self._root = root
 
@@ -760,22 +798,24 @@ class _TabWidget(QtGui.QTabWidget):
         self.tabCloseRequested.connect(self._close_tab)
 
         if not (_TabWidget._spinner_data):
-            _TabWidget._spinner_data = ImageResource('spinner.gif')
+            _TabWidget._spinner_data = ImageResource("spinner.gif")
 
     def show_button(self, index):
         lbl = QtGui.QLabel(self)
-        movie = QtGui.QMovie(_TabWidget._spinner_data.absolute_path, parent=lbl)
-        movie.setCacheMode(QtGui.QMovie.CacheAll)
+        movie = QtGui.QMovie(
+            _TabWidget._spinner_data.absolute_path, parent=lbl
+        )
+        movie.setCacheMode(QtGui.QMovie.CacheMode.CacheAll)
         movie.setScaledSize(QtCore.QSize(16, 16))
         lbl.setMovie(movie)
         movie.start()
-        self.tabBar().setTabButton(index, QtGui.QTabBar.LeftSide, lbl)
+        self.tabBar().setTabButton(index, QtGui.QTabBar.ButtonPosition.LeftSide, lbl)
 
     def hide_button(self, index):
-        curr = self.tabBar().tabButton(index, QtGui.QTabBar.LeftSide)
+        curr = self.tabBar().tabButton(index, QtGui.QTabBar.ButtonPosition.LeftSide)
         if curr:
             curr.close()
-            self.tabBar().setTabButton(index, QtGui.QTabBar.LeftSide, None)
+            self.tabBar().setTabButton(index, QtGui.QTabBar.ButtonPosition.LeftSide, None)
 
     def active_icon(self):
         """ Return the QIcon to be used to indicate an active tab page. """
@@ -805,8 +845,8 @@ class _TabWidget(QtGui.QTabWidget):
 
             # Draw the circle.
             p.setBrush(rg)
-            p.setPen(QtCore.Qt.NoPen)
-            p.setRenderHint(QtGui.QPainter.Antialiasing)
+            p.setPen(QtCore.Qt.PenStyle.NoPen)
+            p.setRenderHint(QtGui.QPainter.RenderHint.Antialiasing)
             p.drawEllipse(0, 0, width, height)
 
             p.end()
@@ -840,7 +880,10 @@ class _TabWidget(QtGui.QTabWidget):
 
         self._still_needed()
 
-        if self._root._current_tab_w is self and self._root._current_tab_idx == idx:
+        if (
+            self._root._current_tab_w is self
+            and self._root._current_tab_idx == idx
+        ):
             self._root._current_tab_w = None
 
     def _close_tab(self, index):
@@ -848,12 +891,14 @@ class _TabWidget(QtGui.QTabWidget):
 
         self._root._close_tab_request(self.widget(index))
 
+
 class _IndependentLineEdit(QtGui.QLineEdit):
     def keyPressEvent(self, e):
         QtGui.QLineEdit.keyPressEvent(self, e)
-        if (e.key() == QtCore.Qt.Key_Escape):
+        if e.key() == QtCore.Qt.Key.Key_Escape:
             self.hide()
 
+
 class _DragableTabBar(QtGui.QTabBar):
     """ The _DragableTabBar class is a QTabBar that can be dragged around. """
 
@@ -863,7 +908,7 @@ class _DragableTabBar(QtGui.QTabBar):
         QtGui.QTabBar.__init__(self, parent)
 
         # XXX this requires Qt > 4.5
-        if sys.platform == 'darwin':
+        if sys.platform == "darwin":
             self.setDocumentMode(True)
 
         self._root = root
@@ -871,8 +916,8 @@ class _DragableTabBar(QtGui.QTabBar):
         # LineEdit to change tab bar title
         te = _IndependentLineEdit("", self)
         te.hide()
-        te.connect(te, QtCore.SIGNAL('editingFinished()'), te, QtCore.SLOT('hide()'))
-        self.connect(te, QtCore.SIGNAL('returnPressed()'), self._setCurrentTabText)
+        te.editingFinished.connect(te.hide)
+        te.returnPressed.connect(self._setCurrentTabText)
         self._title_edit = te
 
     def resizeEvent(self, e):
@@ -884,9 +929,9 @@ class _DragableTabBar(QtGui.QTabBar):
     def keyPressEvent(self, e):
         """ Reimplemented to handle traversal across different tab widgets. """
 
-        if e.key() == QtCore.Qt.Key_Left:
+        if e.key() == QtCore.Qt.Key.Key_Left:
             self._root._move_left(self.parent(), self.currentIndex())
-        elif e.key() == QtCore.Qt.Key_Right:
+        elif e.key() == QtCore.Qt.Key.Key_Right:
             self._root._move_right(self.parent(), self.currentIndex())
         else:
             e.ignore()
@@ -914,7 +959,7 @@ class _DragableTabBar(QtGui.QTabBar):
         self._root._set_current_tab(self.parent(), self.currentIndex())
         self._root._set_focus()
 
-        if e.button() != QtCore.Qt.LeftButton:
+        if e.button() != QtCore.Qt.MouseButton.LeftButton:
             return
 
         if self._drag_state is not None:
@@ -945,15 +990,15 @@ class _DragableTabBar(QtGui.QTabBar):
             # If the mouse has moved far enough that dragging has started then
             # tell the user.
             if self._drag_state.dragging:
-                QtGui.QApplication.setOverrideCursor(QtCore.Qt.OpenHandCursor)
+                QtGui.QApplication.setOverrideCursor(QtCore.Qt.CursorShape.OpenHandCursor)
 
     def mouseReleaseEvent(self, e):
         """ Reimplemented to handle mouse release events. """
 
         QtGui.QTabBar.mouseReleaseEvent(self, e)
 
-        if e.button() != QtCore.Qt.LeftButton:
-            if e.button() == QtCore.Qt.MidButton:
+        if e.button() != QtCore.Qt.MouseButton.LeftButton:
+            if e.button() == QtCore.Qt.MidddleButton:
                 self.tabCloseRequested.emit(self.tabAt(e.pos()))
             return
 
@@ -975,15 +1020,15 @@ class _DragableTabBar(QtGui.QTabBar):
     def _setCurrentTabText(self):
         idx = self.currentIndex()
         text = self._title_edit.text()
-        self.setTabText(idx, u'\u25b6'+text)
-        self._root.emit(QtCore.SIGNAL('tabTextChanged(QWidget *, QString)'), self.parent().widget(idx), text)
+        self.setTabText(idx, "\u25b6" + text)
+        self._root.tabTextChanged.emit(self.parent().widget(idx), text)
 
     def _resize_title_edit_to_current_tab(self):
         idx = self.currentIndex()
         tab = QtGui.QStyleOptionTabV3()
         self.initStyleOption(tab, idx)
-        rect = self.style().subElementRect(QtGui.QStyle.SE_TabBarTabText, tab)
-        self._title_edit.setGeometry(rect.adjusted(0,8,0,-8))
+        rect = self.style().subElementRect(QtGui.QStyle.SubElement.SE_TabBarTabText, tab)
+        self._title_edit.setGeometry(rect.adjusted(0, 8, 0, -8))
 
 
 class _DragState(object):
@@ -1003,7 +1048,9 @@ class _DragState(object):
     def start_dragging(self, pos):
         """ Start dragging a tab. """
 
-        if (pos - self._start_pos).manhattanLength() <= QtGui.QApplication.startDragDistance():
+        if (
+            pos - self._start_pos
+        ).manhattanLength() <= QtGui.QApplication.startDragDistance():
             return
 
         self.dragging = True
@@ -1013,13 +1060,15 @@ class _DragState(object):
         tab = self._tab
 
         ctb = self._clone = QtGui.QTabBar()
-        if sys.platform == 'darwin' and QtCore.QT_VERSION >= 0x40500:
+        if sys.platform == "darwin" and QtCore.QT_VERSION >= 0x40500:
             ctb.setDocumentMode(True)
 
-        ctb.setAttribute(QtCore.Qt.WA_TransparentForMouseEvents)
-        ctb.setWindowFlags(QtCore.Qt.FramelessWindowHint |
-                           QtCore.Qt.Tool |
-                           QtCore.Qt.X11BypassWindowManagerHint)
+        ctb.setAttribute(QtCore.Qt.WidgetAttribute.WA_TransparentForMouseEvents)
+        ctb.setWindowFlags(
+            QtCore.Qt.WindowType.FramelessWindowHint
+            | QtCore.Qt.WindowType.Tool
+            | QtCore.Qt.WindowType.X11BypassWindowManagerHint
+        )
         ctb.setWindowOpacity(0.5)
         ctb.setElideMode(otb.elideMode())
         ctb.setShape(otb.shape())
@@ -1044,8 +1093,9 @@ class _DragState(object):
         """ Handle the movement of the cloned tab during dragging. """
 
         self._clone.move(self._tab_bar.mapToGlobal(pos) + self._clone_offset)
-        self._root._select(self._tab_bar.mapTo(self._root,
-                                               pos + self._centre_offset))
+        self._root._select(
+            self._tab_bar.mapTo(self._root, pos + self._centre_offset)
+        )
 
     def drop(self, pos):
         """ Handle the drop of the cloned tab. """
