@@ -1,40 +1,32 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Enthought, Inc.
-#
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 
 """ Enthought pyface package component
 """
 
-# Standard library imports.
 import sys
 
-# Major package imports.
 import wx
 import wx.html
 import wx.lib.wxpTag
 
-# Enthought library imports.
-from traits.api import Instance, List, provides, Unicode
+from traits.api import List, provides, Str
 
-# Local imports.
 from pyface.i_about_dialog import IAboutDialog, MAboutDialog
-from pyface.image_resource import ImageResource
-from dialog import Dialog
+from pyface.ui_traits import Image
+from .dialog import Dialog
+from .image_resource import ImageResource
 
 
-_DIALOG_TEXT = '''
+_DIALOG_TEXT = """
 <html>
   <body>
     <center>
@@ -54,6 +46,9 @@ _DIALOG_TEXT = '''
       wxPython %s<br>
       </p>
       <p>
+      %s
+      </p>
+      <p>
       Copyright &copy; 2003-2010 Enthought, Inc.
       </p>
 
@@ -66,7 +61,7 @@ _DIALOG_TEXT = '''
   </center>
   </body>
 </html>
-'''
+"""
 
 
 @provides(IAboutDialog)
@@ -75,16 +70,17 @@ class AboutDialog(MAboutDialog, Dialog):
     IAboutDialog interface for the API documentation.
     """
 
+    # 'IAboutDialog' interface ---------------------------------------------
 
-    #### 'IAboutDialog' interface #############################################
+    additions = List(Str)
 
-    additions = List(Unicode)
+    copyrights = List(Str)
 
-    image = Instance(ImageResource, ImageResource('about'))
+    image = Image(ImageResource("about"))
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected 'IDialog' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _create_contents(self, parent):
         if parent.GetParent() is not None:
@@ -98,10 +94,6 @@ class AboutDialog(MAboutDialog, Dialog):
 
         # Load the image to be displayed in the about box.
         image = self.image.create_image()
-        path  = self.image.absolute_path
-
-        # The additional strings.
-        additions = '<br />'.join(self.additions)
 
         # The width of a wx HTML window is fixed (and  is given in the
         # constructor). We set it to the width of the image plus a fudge
@@ -109,23 +101,13 @@ class AboutDialog(MAboutDialog, Dialog):
         width = image.GetWidth() + 80
         html = wx.html.HtmlWindow(parent, -1, size=(width, -1))
 
-        # Get the version numbers.
-        py_version = sys.version[0:sys.version.find("(")]
-        wx_version = wx.VERSION_STRING
-
-        # Get the text of the OK button.
-        if self.ok_label is None:
-            ok = "OK"
-        else:
-            ok = self.ok_label
-
         # Set the page contents.
-        html.SetPage(
-            _DIALOG_TEXT % (path, additions, py_version, wx_version, ok)
-        )
+        html.SetPage(self._create_html())
 
         # Make the 'OK' button the default button.
-        ok_button = html.FindWindowById(wx.ID_OK)
+        ok_button = parent.FindWindowById(
+            wx.ID_OK
+        )  # html.Window.FindWindowById(wx.ID_OK)
         ok_button.SetDefault()
 
         # Set the height of the HTML window to match the height of the content.
@@ -136,7 +118,36 @@ class AboutDialog(MAboutDialog, Dialog):
         # We add a fudge factor to the height here, although I'm not sure why
         # it should be necessary, the HTML window should report its required
         # size!?!
-        width, height = html.GetSize()
+        width, height = html.GetSize().Get()
         parent.SetClientSize((width, height + 10))
 
-### EOF #######################################################################
+    def _create_html(self):
+        # Load the image to be displayed in the about box.
+        path = self.image.absolute_path
+
+        # The additional strings.
+        additions = "<br />".join(self.additions)
+
+        # Get the version numbers.
+        py_version = sys.version[0:sys.version.find("(")]
+        wx_version = wx.VERSION_STRING
+
+        # The additional copyright strings.
+        copyrights = "<br />".join(
+            ["Copyright &copy; %s" % line for line in self.copyrights]
+        )
+
+        # Get the text of the OK button.
+        if self.ok_label is None:
+            ok = "OK"
+        else:
+            ok = self.ok_label
+
+        return _DIALOG_TEXT % (
+            path,
+            additions,
+            py_version,
+            wx_version,
+            copyrights,
+            ok,
+        )
