@@ -1,38 +1,29 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Enthought, Inc.
-#
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 
 """ Enthought pyface package component
 """
 
-# Standard library imports.
-import sys
-
-# Major package imports.
 import wx
-from pyface.wx.aui import aui, PyfaceAuiManager
 
-# Enthought library imports.
+from traits.api import Instance, List, Str, observe, provides
+
 from pyface.action.api import MenuBarManager, StatusBarManager
 from pyface.action.api import ToolBarManager
-from traits.api import Instance, List, on_trait_change, provides, Unicode
-from pyface.i_application_window import IApplicationWindow
-from pyface.i_application_window import MApplicationWindow
-from pyface.image_resource import ImageResource
-
-# Local imports.
+from pyface.i_application_window import (
+    IApplicationWindow, MApplicationWindow,
+)
+from pyface.ui_traits import Image
+from pyface.wx.aui import aui, PyfaceAuiManager
+from .image_resource import ImageResource
 from .window import Window
 
 
@@ -42,10 +33,9 @@ class ApplicationWindow(MApplicationWindow, Window):
     IApplicationWindow interface for the API documentation.
     """
 
+    # 'IApplicationWindow' interface ---------------------------------------
 
-    #### 'IApplicationWindow' interface #######################################
-
-    icon = Instance(ImageResource)
+    icon = Image()
 
     menu_bar_manager = Instance(MenuBarManager)
 
@@ -57,7 +47,7 @@ class ApplicationWindow(MApplicationWindow, Window):
     # this list instead.
     tool_bar_managers = List(ToolBarManager)
 
-    #### 'IWindow' interface ##################################################
+    # 'IWindow' interface -------------------------------------------------#
 
     # fixme: We can't set the default value of the actual 'size' trait here as
     # in the toolkit-specific event handlers for window size and position
@@ -65,19 +55,17 @@ class ApplicationWindow(MApplicationWindow, Window):
     # that by doing that traits never knows that the trait has been set and
     # hence always returns the default value! Using a trait initializer method
     # seems to work however (e.g. 'def _size_default'). Hmmmm....
-##     size = (800, 600)
+    ##     size = (800, 600)
 
-    title = Unicode("Pyface")
+    title = Str("Pyface")
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected 'IApplicationWindow' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _create_contents(self, parent):
         panel = wx.Panel(parent, -1, name="ApplicationWindow")
-        panel.SetSize((500, 400))
-        panel.SetBackgroundColour('blue')
-
+        panel.SetBackgroundColour("blue")
         return panel
 
     def _create_menu_bar(self, parent):
@@ -90,45 +78,38 @@ class ApplicationWindow(MApplicationWindow, Window):
             status_bar = self.status_bar_manager.create_status_bar(parent)
             self.control.SetStatusBar(status_bar)
 
-        return
-
     def _create_tool_bar(self, parent):
         tool_bar_managers = self._get_tool_bar_managers()
         if len(tool_bar_managers) > 0:
             for tool_bar_manager in reversed(tool_bar_managers):
                 tool_bar = tool_bar_manager.create_tool_bar(parent, aui=True)
-                self._add_toolbar_to_aui_manager(
-                    tool_bar
-                )
+                self._add_toolbar_to_aui_manager(tool_bar)
             self._aui_manager.Update()
 
     def _set_window_icon(self):
         if self.icon is None:
-            icon = ImageResource('application.ico')
+            icon = ImageResource("application.ico")
         else:
             icon = self.icon
 
         if self.control is not None:
             self.control.SetIcon(icon.create_icon())
 
-        return
-
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'Window' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _size_default(self):
         """ Trait initialiser. """
-
         return (800, 600)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected 'IWidget' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _create(self):
 
-        super(ApplicationWindow, self)._create()
+        super()._create()
 
         self._aui_manager = PyfaceAuiManager()
         self._aui_manager.SetManagedWindow(self.control)
@@ -138,6 +119,7 @@ class ApplicationWindow(MApplicationWindow, Window):
         self.control._aui_manager = self._aui_manager
 
         contents = self._create_contents(self.control)
+        self._aui_manager.AddPane(contents, aui.AuiPaneInfo().CenterPane())
 
         self._create_trim_widgets(self.control)
 
@@ -145,17 +127,19 @@ class ApplicationWindow(MApplicationWindow, Window):
         # to it (this allows batch updates).
         self._aui_manager.Update()
 
-        return
-
     def _create_control(self, parent):
 
-        style = wx.DEFAULT_FRAME_STYLE \
-                | wx.FRAME_NO_WINDOW_MENU \
-                | wx.CLIP_CHILDREN
+        style = (
+            wx.DEFAULT_FRAME_STYLE | wx.FRAME_NO_WINDOW_MENU | wx.CLIP_CHILDREN
+        )
 
         control = wx.Frame(
-            parent, -1, self.title, style=style, size=self.size,
-            pos=self.position
+            parent,
+            -1,
+            self.title,
+            style=style,
+            size=self.size,
+            pos=self.position,
         )
 
         # Mac/Win needs this, otherwise background color is black
@@ -167,11 +151,11 @@ class ApplicationWindow(MApplicationWindow, Window):
     def destroy(self):
         if self.control:
             self._aui_manager.UnInit()
-        super(ApplicationWindow, self).destroy()
+        super().destroy()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _add_toolbar_to_aui_manager(self, tool_bar):
         """ Add a toolbar to the AUI manager. """
@@ -179,8 +163,6 @@ class ApplicationWindow(MApplicationWindow, Window):
         info = self._get_tool_bar_pane_info(tool_bar)
         self._aui_manager.AddPane(tool_bar, info)
 
-        return
-
     def _get_tool_bar_pane_info(self, tool_bar):
         info = aui.AuiPaneInfo()
         info.Caption(tool_bar.tool_bar_manager.name)
@@ -209,8 +191,6 @@ class ApplicationWindow(MApplicationWindow, Window):
 
         # AUI toolbars cannot be enabled/disabled.
 
-        return
-
     def _wx_show_tool_bar(self, tool_bar, visible):
         """ Hide/Show a tool bar. """
 
@@ -232,7 +212,7 @@ class ApplicationWindow(MApplicationWindow, Window):
 
         return
 
-    #### Trait change handlers ################################################
+    # Trait change handlers ------------------------------------------------
 
     def _menu_bar_manager_changed(self):
         if self.control is not None:
@@ -245,12 +225,10 @@ class ApplicationWindow(MApplicationWindow, Window):
                 old.remove_status_bar(self.control)
             self._create_status_bar(self.control)
 
-    @on_trait_change('tool_bar_manager, tool_bar_managers')
-    def _update_tool_bar_managers(self):
+    @observe("tool_bar_manager, tool_bar_managers.items")
+    def _update_tool_bar_managers(self, event):
         if self.control is not None:
             self._create_tool_bar(self.control)
 
     def _icon_changed(self):
         self._set_window_icon()
-
-#### EOF ######################################################################
