@@ -1,33 +1,30 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: Enthought, Inc.
-#
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 
 """ Enthought pyface package component
 """
 
-# Major package imports.
+
 import wx
 
-# Enthought library imports.
-from traits.api import Bool, Enum, Instance, provides, Unicode
+from traits.api import Bool, Enum, provides, Str
 
-# Local imports.
-from pyface.i_confirmation_dialog import IConfirmationDialog, MConfirmationDialog
+from pyface.i_confirmation_dialog import (
+    IConfirmationDialog,
+    MConfirmationDialog,
+)
 from pyface.constant import CANCEL, YES, NO
-from pyface.image_resource import ImageResource
-from dialog import Dialog
+from pyface.ui_traits import Image
+from .dialog import Dialog
+from .image_resource import ImageResource
 
 
 @provides(IConfirmationDialog)
@@ -36,31 +33,30 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
     IConfirmationDialog interface for the API documentation.
     """
 
-
-    #### 'IConfirmationDialog' interface ######################################
+    # 'IConfirmationDialog' interface -------------------------------------#
 
     cancel = Bool(False)
 
     default = Enum(NO, YES, CANCEL)
 
-    image = Instance(ImageResource)
+    image = Image()
 
-    message = Unicode
+    message = Str()
 
-    informative = Unicode
+    informative = Str()
 
-    detail = Unicode
+    detail = Str()
 
-    no_label = Unicode
+    no_label = Str()
 
-    yes_label = Unicode
+    yes_label = Str()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Protected 'IDialog' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _create_buttons(self, parent):
-        sizer = wx.BoxSizer(wx.HORIZONTAL)
+        sizer = wx.StdDialogButtonSizer()
 
         # 'YES' button.
         if self.yes_label:
@@ -71,8 +67,8 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
         self._yes = yes = wx.Button(parent, wx.ID_YES, label)
         if self.default == YES:
             yes.SetDefault()
-        wx.EVT_BUTTON(parent, wx.ID_YES, self._on_yes)
-        sizer.Add(yes)
+        parent.Bind(wx.EVT_BUTTON, self._on_yes, yes)
+        sizer.AddButton(yes)
 
         # 'NO' button.
         if self.no_label:
@@ -83,8 +79,8 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
         self._no = no = wx.Button(parent, wx.ID_NO, label)
         if self.default == NO:
             no.SetDefault()
-        wx.EVT_BUTTON(parent, wx.ID_NO, self._on_no)
-        sizer.Add(no, 0, wx.LEFT, 10)
+        parent.Bind(wx.EVT_BUTTON, self._on_no, no)
+        sizer.AddButton(no)
 
         if self.cancel:
             # 'Cancel' button.
@@ -97,9 +93,10 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
             if self.default == CANCEL:
                 cancel.SetDefault()
 
-            wx.EVT_BUTTON(parent, wx.ID_CANCEL, self._wx_on_cancel)
-            sizer.Add(cancel, 0, wx.LEFT, 10)
+            parent.Bind(wx.EVT_BUTTON, self._wx_on_cancel, cancel)
+            sizer.AddButton(cancel)
 
+        sizer.Realize()
         return sizer
 
     def _create_dialog_area(self, parent):
@@ -110,7 +107,7 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
 
         # The image.
         if self.image is None:
-            image_rc = ImageResource('warning')
+            image_rc = ImageResource("warning")
         else:
             image_rc = self.image
 
@@ -119,7 +116,7 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
 
         # The message.
         if self.informative:
-            message = self.message + '\n\n' + self.informative
+            message = self.message + "\n\n" + self.informative
         else:
             message = self.message
         message = wx.StaticText(panel, -1, message)
@@ -130,11 +127,11 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
 
         return panel
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
-    #### wx event handlers ####################################################
+    # wx event handlers ----------------------------------------------------
 
     def _on_yes(self, event):
         """ Called when the 'Yes' button is pressed. """
@@ -145,5 +142,3 @@ class ConfirmationDialog(MConfirmationDialog, Dialog):
         """ Called when the 'No' button is pressed. """
 
         self.control.EndModal(wx.ID_NO)
-
-#### EOF ######################################################################
