@@ -1,16 +1,18 @@
-# Copyright (c) 2017, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A viewer based on a table control. """
 
 
 # Import the toolkit specific version.
-from __future__ import absolute_import
+
 
 from pyface.toolkit import toolkit_object
-TableViewer = toolkit_object('viewer.table_viewer:TableViewer')
+
+TableViewer = toolkit_object("viewer.table_viewer:TableViewer")
