@@ -1,20 +1,16 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ Abstract base class for tree content providers. """
 
 
-# Local imports.
 from .content_provider import ContentProvider
 
 
@@ -25,9 +21,9 @@ class TreeContentProvider(ContentProvider):
 
     """
 
-    #########################################################################
+    # ------------------------------------------------------------------------
     # 'ContentProvider' interface.
-    #########################################################################
+    # ------------------------------------------------------------------------
 
     def get_elements(self, element):
         """ Returns a list of the elements to display in a viewer.
@@ -39,11 +35,11 @@ class TreeContentProvider(ContentProvider):
 
         """
 
-        return get_children(element)
+        return self.get_children(element)
 
-    #########################################################################
+    # ------------------------------------------------------------------------
     # 'TreeContentProvider' interface.
-    #########################################################################
+    # ------------------------------------------------------------------------
 
     def get_parent(self, element):
         """ Returns the parent of an element.
@@ -58,11 +54,9 @@ class TreeContentProvider(ContentProvider):
     def get_children(self, element):
         """ Returns the children of an element. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def has_children(self, element):
         """ Returns True iff the element has children, otherwise False. """
 
-        raise NotImplementedError
-
-#### EOF ####################################################################
+        raise NotImplementedError()
