@@ -1,31 +1,30 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ A wizard controller that has a static list of pages. """
 
 
-# Enthought library imports.
-from traits.api import Bool, HasTraits, Instance, List, Property, provides
+from traits.api import (
+    Bool, HasTraits, Instance, List, Property, provides, observe
+)
 
-# Local imports.
-from i_wizard_controller import IWizardController
-from i_wizard_page import IWizardPage
+
+from .i_wizard_controller import IWizardController
+from .i_wizard_page import IWizardPage
 
 
 @provides(IWizardController)
 class WizardController(HasTraits):
     """ A wizard controller that has a static list of pages. """
-    #### 'IWizardController' interface ########################################
+
+    # 'IWizardController' interface ----------------------------------------
 
     # The pages under the control of this controller.
     pages = Property(List(IWizardPage))
@@ -36,14 +35,14 @@ class WizardController(HasTraits):
     # Set if the wizard is complete.
     complete = Bool(False)
 
-    #### Protected 'IWizardController' interface ##############################
+    # Protected 'IWizardController' interface -----------------------------#
 
     # Shadow trait for the 'pages' property.
     _pages = List(IWizardPage)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'IWizardController' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def get_first_page(self):
         """ Returns the first page. """
@@ -107,9 +106,9 @@ class WizardController(HasTraits):
 
         return
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'WizardController' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _get_pages(self):
         """ Returns the pages in the wizard. """
@@ -125,17 +124,19 @@ class WizardController(HasTraits):
         # If the current page is None (i.e., the current page has
         # not been set yet), do not set it here. The current page will
         # get set when the wizard calls _show_page.
-        if self.current_page is not None and \
-            self.current_page not in self._pages:
+        if (
+            self.current_page is not None
+            and self.current_page not in self._pages
+        ):
             self.current_page = self._pages[0]
         else:
             self._update()
 
         return
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _update(self):
         """ Checks the completion status of the controller. """
@@ -150,30 +151,31 @@ class WizardController(HasTraits):
 
         return
 
-    #### Trait event handlers #################################################
+    # Trait event handlers -------------------------------------------------
 
-    #### Static ####
+    # Static ----
 
-    def _current_page_changed(self, old, new):
+    @observe("current_page")
+    def _reset_observers_on_current_page_and_update(self, event):
         """ Called when the current page is changed. """
-
+        old, new = event.old, event.new
         if old is not None:
-            old.on_trait_change(self._on_page_complete, 'complete',remove=True)
+            old.observe(
+                self._on_page_complete, "complete", remove=True
+            )
 
         if new is not None:
-            new.on_trait_change(self._on_page_complete, 'complete')
+            new.observe(self._on_page_complete, "complete")
 
         self._update()
 
         return
 
-    #### Dynamic ####
+    # Dynamic ----
 
-    def _on_page_complete(self, obj, trait_name, old, new):
+    def _on_page_complete(self, event):
         """ Called when the current page is complete. """
 
         self._update()
 
         return
-
-#### EOF ######################################################################
