@@ -1,10 +1,18 @@
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ The action controller for workbench menu and tool bars. """
 
 
-# Enthought library imports.
 from pyface.action.api import ActionController
 from pyface.workbench.api import WorkbenchWindow
-from traits.api import HasTraits, Instance
+from traits.api import Instance
 
 
 class ActionController(ActionController):
@@ -17,14 +25,14 @@ class ActionController(ActionController):
 
     """
 
-    #### 'ActionController' interface #########################################
+    # 'ActionController' interface -----------------------------------------
 
     # The workbench window that this is the controller for.
     window = Instance(WorkbenchWindow)
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'ActionController' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def perform(self, action, event):
         """ Control an action invocation. """
@@ -33,5 +41,3 @@ class ActionController(ActionController):
         event.window = self.window
 
         return action.perform(event)
-
-#### EOF ######################################################################
