@@ -1,15 +1,23 @@
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ The 'View' menu """
 
 
-# Standard library imports.
 import logging
 
-# Enthought library imports.
-from pyface.action.api import Group, MenuManager
-from traits.api import Any, Bool, Instance, List, Str, Unicode
-from traits.api import on_trait_change
 
-# Local imports.
+from pyface.action.api import Group, MenuManager
+from traits.api import Any, Bool, Instance, List, Str
+from traits.api import observe
+
+
 from .perspective_menu_manager import PerspectiveMenuManager
 from .show_view_action import ShowViewAction
 from .toggle_view_visibility_action import ToggleViewVisibilityAction
@@ -26,36 +34,36 @@ class ViewMenuManager(MenuManager):
 
     """
 
-    #### 'ActionManager' interface ############################################
+    # 'ActionManager' interface --------------------------------------------
 
     # All of the groups in the manager.
     groups = List(Group)
 
     # The manager's unique identifier (if it has one).
-    id = Str('View')
+    id = Str("View")
 
-    #### 'MenuManager' interface ##############################################
+    # 'MenuManager' interface ---------------------------------------------#
 
     # The menu manager's name (if the manager is a sub-menu, this is what its
     # label will be).
-    name = Unicode('&View')
+    name = Str("&View")
 
-    #### 'ViewMenuManager' interface ##########################################
+    # 'ViewMenuManager' interface -----------------------------------------#
 
     # Should the perspective menu be shown?
     show_perspective_menu = Bool(True)
 
     # The workbench window that the menu is part of.
-    window = Instance('pyface.workbench.api.WorkbenchWindow')
+    window = Instance("pyface.workbench.api.WorkbenchWindow")
 
-    #### 'Private' interface ##################################################
+    # 'Private' interface -------------------------------------------------#
 
     # The group containing the view hide/show actions.
-    _view_group = Any
+    _view_group = Any()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'ActionManager' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _groups_default(self):
         """ Trait initializer. """
@@ -76,18 +84,15 @@ class ViewMenuManager(MenuManager):
 
         return groups
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'ViewMenuManager' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
-    @on_trait_change(
-        'window.active_perspective,window.active_part,'
-        'window.views,window.views_items'
-    )
-    def refresh(self):
+    @observe("window.active_perspective,window.active_part,window.views.items")
+    def refresh(self, event):
         """ Refreshes the checked state of the actions in the menu. """
 
-        logger.debug('refreshing view menu')
+        logger.debug("refreshing view menu")
 
         if self._view_group is not None:
             self._clear_group(self._view_group)
@@ -96,9 +101,9 @@ class ViewMenuManager(MenuManager):
 
         return
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _clear_group(self, group):
         """ Remove all items in a group. """
@@ -107,13 +112,11 @@ class ViewMenuManager(MenuManager):
         group.destroy()
         group.clear()
 
-        return
-
     def _create_other_group(self, window):
         """ Creates a group containing the 'Other...' action. """
 
         group = Group()
-        group.append(ShowViewAction(name='Other...', window=window))
+        group.append(ShowViewAction(name="Other...", window=window))
 
         return group
 
@@ -141,5 +144,3 @@ class ViewMenuManager(MenuManager):
                 )
 
         return
-
-#### EOF ######################################################################
