@@ -1,7 +1,15 @@
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ The editor manager interface. """
 
 
-# Enthought library imports.
 from traits.api import Instance, Interface
 
 
@@ -9,7 +17,7 @@ class IEditorManager(Interface):
     """ The editor manager interface. """
 
     # The workbench window that the editor manager manages editors for ;^)
-    window = Instance('pyface.workbench.api.WorkbenchWindow')
+    window = Instance("pyface.workbench.api.WorkbenchWindow")
 
     def add_editor(self, editor, kind):
         """ Registers an existing editor. """
@@ -41,5 +49,3 @@ class IEditorManager(Interface):
 
     def set_editor_memento(self, memento):
         """ Restore an editor from a memento and return it. """
-
-#### EOF ######################################################################
