@@ -1,22 +1,17 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought util package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ A cached image list. """
 
 
-# Major package imports.
 import wx
-import six
 
 
 # fixme: rename to 'CachedImageList'?!?
@@ -33,13 +28,13 @@ class ImageList(wx.ImageList):
         self._height = height
 
         # Cache of the indexes of the images in the list!
-        self._cache = {} # {filename : index}
+        self._cache = {}  # {filename : index}
 
         return
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'ImageList' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def GetIndex(self, filename):
         """ Returns the index of the specified image.
@@ -51,14 +46,14 @@ class ImageList(wx.ImageList):
 
         # If the icon is a string then it is the filename of some kind of
         # image (e.g 'foo.gif', 'image/foo.png' etc).
-        if isinstance(filename, six.string_types):
+        if isinstance(filename, str):
             # Try the cache first.
             index = self._cache.get(filename)
             if index is None:
                 # Load the image from the file and add it to the list.
                 #
                 # N.B 'wx.BITMAP_TYPE_ANY' tells wxPython to attempt to
-                # ---- autodetect the image format.
+                # autodetect the image format.
                 image = wx.Image(filename, wx.BITMAP_TYPE_ANY)
 
                 # We force all images in the cache to be the same size.
@@ -76,17 +71,17 @@ class ImageList(wx.ImageList):
         # Otherwise the icon is *actually* an icon (in our case, probably
         # related to a MIME type).
         else:
-            #image = filename
-            #self._scale(image)
-            #bmp = image.ConvertToBitmap()
-            #index = self.Add(bmp)
+            # image = filename
+            # self._scale(image)
+            # bmp = image.ConvertToBitmap()
+            # index = self.Add(bmp)
 
-            #return index
+            # return index
 
             icon = filename
 
             # We also force them to be bitmaps!
-            bmp = wx.EmptyBitmap(self._width, self._height)
+            bmp = wx.Bitmap(self._width, self._height)
             bmp.CopyFromIcon(icon)
             # We force all images in the cache to be the same size.
             image = wx.ImageFromBitmap(bmp)
@@ -98,16 +93,17 @@ class ImageList(wx.ImageList):
 
         return index
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # Private interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def _scale(self, image):
         """ Scales the specified image (if necessary). """
 
-        if image.GetWidth() != self._width or image.GetHeight()!= self._height:
+        if (
+            image.GetWidth() != self._width
+            or image.GetHeight() != self._height
+        ):
             image.Rescale(self._width, self._height)
 
         return image
-
-#### EOF ######################################################################
