@@ -1,20 +1,16 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought util package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ A panel sized by a sizer. """
 
 
-# Major package imports.
 import wx
 
 
@@ -37,22 +33,18 @@ class SizedPanel(wx.Panel):
 
         return
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'SizedPanel' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def Fit(self):
         """ Resizes the panel to match the sizer's minimal size. """
 
         self.sizer.Fit(self)
 
-        return
-
     def Layout(self):
         """ Lays out the sizer without changing the panel geometry. """
 
         self.sizer.Layout()
 
         return
-
-#### EOF ######################################################################
